"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import account_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ActivenessProbeResponse:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ActivenessProbeResponseEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ActivenessProbeResponse.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ACTIVENESS_PROBE_RESPONSE_UNKNOWN: _ActivenessProbeResponse.ValueType  # 0
    ACTIVENESS_PROBE_RESPONSE_STILL_ACTIVE: _ActivenessProbeResponse.ValueType  # 1
    ACTIVENESS_PROBE_RESPONSE_NO_LONGER_ACTIVE: _ActivenessProbeResponse.ValueType  # 2

class ActivenessProbeResponse(_ActivenessProbeResponse, metaclass=_ActivenessProbeResponseEnumTypeWrapper): ...

ACTIVENESS_PROBE_RESPONSE_UNKNOWN: ActivenessProbeResponse.ValueType  # 0
ACTIVENESS_PROBE_RESPONSE_STILL_ACTIVE: ActivenessProbeResponse.ValueType  # 1
ACTIVENESS_PROBE_RESPONSE_NO_LONGER_ACTIVE: ActivenessProbeResponse.ValueType  # 2
Global___ActivenessProbeResponse: typing_extensions.TypeAlias = ActivenessProbeResponse

@typing.final
class JailInfoRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JAILED_FIELD_NUMBER: builtins.int
    HAS_NOT_ACCEPTED_TOS_FIELD_NUMBER: builtins.int
    NEEDS_TO_UPDATE_LOCATION_FIELD_NUMBER: builtins.int
    HAS_NOT_ACCEPTED_COMMUNITY_GUIDELINES_FIELD_NUMBER: builtins.int
    HAS_PENDING_MOD_NOTES_FIELD_NUMBER: builtins.int
    PENDING_MOD_NOTES_FIELD_NUMBER: builtins.int
    HAS_PENDING_ACTIVENESS_PROBE_FIELD_NUMBER: builtins.int
    jailed: builtins.bool
    has_not_accepted_tos: builtins.bool
    needs_to_update_location: builtins.bool
    has_not_accepted_community_guidelines: builtins.bool
    has_pending_mod_notes: builtins.bool
    """mod notes"""
    has_pending_activeness_probe: builtins.bool
    @property
    def pending_mod_notes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[account_pb2.ModNote]:
        """the actual mod notes, if any
        will be empty iff has_mode_notes is false
        """

    def __init__(
        self,
        *,
        jailed: builtins.bool | None = ...,
        has_not_accepted_tos: builtins.bool | None = ...,
        needs_to_update_location: builtins.bool | None = ...,
        has_not_accepted_community_guidelines: builtins.bool | None = ...,
        has_pending_mod_notes: builtins.bool | None = ...,
        pending_mod_notes: collections.abc.Iterable[account_pb2.ModNote] | None = ...,
        has_pending_activeness_probe: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["has_not_accepted_community_guidelines", b"has_not_accepted_community_guidelines", "has_not_accepted_tos", b"has_not_accepted_tos", "has_pending_activeness_probe", b"has_pending_activeness_probe", "has_pending_mod_notes", b"has_pending_mod_notes", "jailed", b"jailed", "needs_to_update_location", b"needs_to_update_location", "pending_mod_notes", b"pending_mod_notes"]) -> None: ...

Global___JailInfoRes: typing_extensions.TypeAlias = JailInfoRes

@typing.final
class AcceptTOSReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCEPT_FIELD_NUMBER: builtins.int
    accept: builtins.bool
    def __init__(
        self,
        *,
        accept: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["accept", b"accept"]) -> None: ...

Global___AcceptTOSReq: typing_extensions.TypeAlias = AcceptTOSReq

@typing.final
class SetLocationReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CITY_FIELD_NUMBER: builtins.int
    LAT_FIELD_NUMBER: builtins.int
    LNG_FIELD_NUMBER: builtins.int
    RADIUS_FIELD_NUMBER: builtins.int
    city: builtins.str
    lat: builtins.float
    lng: builtins.float
    radius: builtins.float
    """meters"""
    def __init__(
        self,
        *,
        city: builtins.str | None = ...,
        lat: builtins.float | None = ...,
        lng: builtins.float | None = ...,
        radius: builtins.float | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["city", b"city", "lat", b"lat", "lng", b"lng", "radius", b"radius"]) -> None: ...

Global___SetLocationReq: typing_extensions.TypeAlias = SetLocationReq

@typing.final
class AcceptCommunityGuidelinesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCEPT_FIELD_NUMBER: builtins.int
    accept: builtins.bool
    def __init__(
        self,
        *,
        accept: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["accept", b"accept"]) -> None: ...

Global___AcceptCommunityGuidelinesReq: typing_extensions.TypeAlias = AcceptCommunityGuidelinesReq

@typing.final
class AcknowledgePendingModNoteReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NOTE_ID_FIELD_NUMBER: builtins.int
    ACKNOWLEDGE_FIELD_NUMBER: builtins.int
    note_id: builtins.int
    acknowledge: builtins.bool
    """whether the user acknowledges the note or not"""
    def __init__(
        self,
        *,
        note_id: builtins.int | None = ...,
        acknowledge: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["acknowledge", b"acknowledge", "note_id", b"note_id"]) -> None: ...

Global___AcknowledgePendingModNoteReq: typing_extensions.TypeAlias = AcknowledgePendingModNoteReq

@typing.final
class RespondToActivenessProbeReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESPONSE_FIELD_NUMBER: builtins.int
    response: Global___ActivenessProbeResponse.ValueType
    def __init__(
        self,
        *,
        response: Global___ActivenessProbeResponse.ValueType | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["response", b"response"]) -> None: ...

Global___RespondToActivenessProbeReq: typing_extensions.TypeAlias = RespondToActivenessProbeReq
