# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notifications.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13notifications.proto\x12\x1aorg.couchers.notifications\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"\x1c\n\x1aGetNotificationSettingsReq\"{\n\x10NotificationItem\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x15\n\ruser_editable\x18\x03 \x01(\x08\x12\x0c\n\x04push\x18\x04 \x01(\x08\x12\r\n\x05\x65mail\x18\x05 \x01(\x08\x12\x0e\n\x06\x64igest\x18\x06 \x01(\x08\"m\n\x11NotificationTopic\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12;\n\x05items\x18\x03 \x03(\x0b\x32,.org.couchers.notifications.NotificationItem\"c\n\x11NotificationGroup\x12\x0f\n\x07heading\x18\x01 \x01(\t\x12=\n\x06topics\x18\x02 \x03(\x0b\x32-.org.couchers.notifications.NotificationTopic\"g\n\x1cSingleNotificationPreference\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65livery_method\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\"\x97\x01\n\x1aGetNotificationSettingsRes\x12\x1c\n\x14\x64o_not_email_enabled\x18\x01 \x01(\x08\x12\x1c\n\x14\x65mail_digest_enabled\x18\x02 \x01(\x08\x12=\n\x06groups\x18\x03 \x03(\x0b\x32-.org.couchers.notifications.NotificationGroup\"\x88\x01\n\x1aSetNotificationSettingsReq\x12\x1b\n\x13\x65nable_do_not_email\x18\x01 \x01(\x08\x12M\n\x0bpreferences\x18\x02 \x03(\x0b\x32\x38.org.couchers.notifications.SingleNotificationPreference\"\xc9\x01\n\x0cNotification\x12\x17\n\x0fnotification_id\x18\x01 \x01(\x03\x12+\n\x07\x63reated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05topic\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t\x12\x0b\n\x03key\x18\x05 \x01(\t\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0c\n\x04\x62ody\x18\x07 \x01(\t\x12\x0c\n\x04icon\x18\x08 \x01(\t\x12\x0b\n\x03url\x18\t \x01(\t\x12\x0f\n\x07is_seen\x18\n \x01(\x08\"R\n\x14ListNotificationsReq\x12\x13\n\x0bonly_unread\x18\x03 \x01(\x08\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"p\n\x14ListNotificationsRes\x12?\n\rnotifications\x18\x01 \x03(\x0b\x32(.org.couchers.notifications.Notification\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"D\n\x17MarkNotificationSeenReq\x12\x17\n\x0fnotification_id\x18\x01 \x01(\x03\x12\x10\n\x08set_seen\x18\x02 \x01(\x08\"=\n\x1bMarkAllNotificationsSeenReq\x12\x1e\n\x16latest_notification_id\x18\x01 \x01(\x03\"0\n\x14GetVapidPublicKeyRes\x12\x18\n\x10vapid_public_key\x18\x01 \x01(\t\"]\n\'RegisterPushNotificationSubscriptionReq\x12\x1e\n\x16\x66ull_subscription_json\x18\x01 \x01(\t\x12\x12\n\nuser_agent\x18\x02 \x01(\t\"h\n-RegisterMobilePushNotificationSubscriptionReq\x12\r\n\x05token\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x03 \x01(\t2\x8d\t\n\rNotifications\x12\x89\x01\n\x17GetNotificationSettings\x12\x36.org.couchers.notifications.GetNotificationSettingsReq\x1a\x36.org.couchers.notifications.GetNotificationSettingsRes\x12\x89\x01\n\x17SetNotificationSettings\x12\x36.org.couchers.notifications.SetNotificationSettingsReq\x1a\x36.org.couchers.notifications.GetNotificationSettingsRes\x12w\n\x11ListNotifications\x12\x30.org.couchers.notifications.ListNotificationsReq\x1a\x30.org.couchers.notifications.ListNotificationsRes\x12\x63\n\x14MarkNotificationSeen\x12\x33.org.couchers.notifications.MarkNotificationSeenReq\x1a\x16.google.protobuf.Empty\x12k\n\x18MarkAllNotificationsSeen\x12\x37.org.couchers.notifications.MarkAllNotificationsSeenReq\x1a\x16.google.protobuf.Empty\x12]\n\x11GetVapidPublicKey\x12\x16.google.protobuf.Empty\x1a\x30.org.couchers.notifications.GetVapidPublicKeyRes\x12\x83\x01\n$RegisterPushNotificationSubscription\x12\x43.org.couchers.notifications.RegisterPushNotificationSubscriptionReq\x1a\x16.google.protobuf.Empty\x12J\n\x18SendTestPushNotification\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x12\x8f\x01\n*RegisterMobilePushNotificationSubscription\x12I.org.couchers.notifications.RegisterMobilePushNotificationSubscriptionReq\x1a\x16.google.protobuf.Empty\x12P\n\x1eSendTestMobilePushNotification\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_NOTIFICATIONS']._loaded_options = None
  _globals['_NOTIFICATIONS']._serialized_options = b'\210\265\030\003'
  _globals['_GETNOTIFICATIONSETTINGSREQ']._serialized_start=132
  _globals['_GETNOTIFICATIONSETTINGSREQ']._serialized_end=160
  _globals['_NOTIFICATIONITEM']._serialized_start=162
  _globals['_NOTIFICATIONITEM']._serialized_end=285
  _globals['_NOTIFICATIONTOPIC']._serialized_start=287
  _globals['_NOTIFICATIONTOPIC']._serialized_end=396
  _globals['_NOTIFICATIONGROUP']._serialized_start=398
  _globals['_NOTIFICATIONGROUP']._serialized_end=497
  _globals['_SINGLENOTIFICATIONPREFERENCE']._serialized_start=499
  _globals['_SINGLENOTIFICATIONPREFERENCE']._serialized_end=602
  _globals['_GETNOTIFICATIONSETTINGSRES']._serialized_start=605
  _globals['_GETNOTIFICATIONSETTINGSRES']._serialized_end=756
  _globals['_SETNOTIFICATIONSETTINGSREQ']._serialized_start=759
  _globals['_SETNOTIFICATIONSETTINGSREQ']._serialized_end=895
  _globals['_NOTIFICATION']._serialized_start=898
  _globals['_NOTIFICATION']._serialized_end=1099
  _globals['_LISTNOTIFICATIONSREQ']._serialized_start=1101
  _globals['_LISTNOTIFICATIONSREQ']._serialized_end=1183
  _globals['_LISTNOTIFICATIONSRES']._serialized_start=1185
  _globals['_LISTNOTIFICATIONSRES']._serialized_end=1297
  _globals['_MARKNOTIFICATIONSEENREQ']._serialized_start=1299
  _globals['_MARKNOTIFICATIONSEENREQ']._serialized_end=1367
  _globals['_MARKALLNOTIFICATIONSSEENREQ']._serialized_start=1369
  _globals['_MARKALLNOTIFICATIONSSEENREQ']._serialized_end=1430
  _globals['_GETVAPIDPUBLICKEYRES']._serialized_start=1432
  _globals['_GETVAPIDPUBLICKEYRES']._serialized_end=1480
  _globals['_REGISTERPUSHNOTIFICATIONSUBSCRIPTIONREQ']._serialized_start=1482
  _globals['_REGISTERPUSHNOTIFICATIONSUBSCRIPTIONREQ']._serialized_end=1575
  _globals['_REGISTERMOBILEPUSHNOTIFICATIONSUBSCRIPTIONREQ']._serialized_start=1577
  _globals['_REGISTERMOBILEPUSHNOTIFICATIONSUBSCRIPTIONREQ']._serialized_end=1681
  _globals['_NOTIFICATIONS']._serialized_start=1684
  _globals['_NOTIFICATIONS']._serialized_end=2849
# @@protoc_insertion_point(module_scope)
