from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import communities_pb2
import editor_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class EditorServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateCommunity(
        self,
        request: editor_pb2.CreateCommunityReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[communities_pb2.Community, collections.abc.Awaitable[communities_pb2.Community]]: ...

    @abc.abstractmethod
    def UpdateCommunity(
        self,
        request: editor_pb2.UpdateCommunityReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[communities_pb2.Community, collections.abc.Awaitable[communities_pb2.Community]]: ...

    @abc.abstractmethod
    def ListEventCommunityInviteRequests(
        self,
        request: editor_pb2.ListEventCommunityInviteRequestsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[editor_pb2.ListEventCommunityInviteRequestsRes, collections.abc.Awaitable[editor_pb2.ListEventCommunityInviteRequestsRes]]: ...

    @abc.abstractmethod
    def DecideEventCommunityInviteRequest(
        self,
        request: editor_pb2.DecideEventCommunityInviteRequestReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[editor_pb2.DecideEventCommunityInviteRequestRes, collections.abc.Awaitable[editor_pb2.DecideEventCommunityInviteRequestRes]]: ...

    @abc.abstractmethod
    def SendBlogPostNotification(
        self,
        request: editor_pb2.SendBlogPostNotificationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def MakeUserVolunteer(
        self,
        request: editor_pb2.MakeUserVolunteerReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[editor_pb2.Volunteer, collections.abc.Awaitable[editor_pb2.Volunteer]]: ...

    @abc.abstractmethod
    def UpdateVolunteer(
        self,
        request: editor_pb2.UpdateVolunteerReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[editor_pb2.Volunteer, collections.abc.Awaitable[editor_pb2.Volunteer]]: ...

    @abc.abstractmethod
    def ListVolunteers(
        self,
        request: editor_pb2.ListVolunteersReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[editor_pb2.ListVolunteersRes, collections.abc.Awaitable[editor_pb2.ListVolunteersRes]]: ...

def add_EditorServicer_to_server(servicer: EditorServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
