# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x61\x64min.proto\x12\x12org.couchers.admin\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\"\x8e\x04\n\x0bUserDetails\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x0e \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x0e\n\x06gender\x18\x04 \x01(\t\x12\x11\n\tbirthdate\x18\x07 \x01(\t\x12\x0e\n\x06\x62\x61nned\x18\x05 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x06 \x01(\x08\x12\x14\n\x0c\x64o_not_email\x18\x0f \x01(\x08\x12\x0e\n\x06\x62\x61\x64ges\x18\x08 \x03(\t\x12\x1f\n\x17has_strong_verification\x18\t \x01(\x08\x12Y\n\x1d\x62irthdate_verification_status\x18\n \x01(\x0e\x32\x32.org.couchers.api.core.BirthdateVerificationStatus\x12S\n\x1agender_verification_status\x18\x0b \x01(\x0e\x32/.org.couchers.api.core.GenderVerificationStatus\x12)\n!has_passport_sex_gender_exception\x18\x0c \x01(\x08\x12\x12\n\nadmin_note\x18\r \x01(\t\x12\x1f\n\x17pending_mod_notes_count\x18\x10 \x01(\x03\x12$\n\x1c\x61\x63knowledged_mod_notes_count\x18\x11 \x01(\x03\"!\n\x11GetUserDetailsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1a\n\nGetUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x86\x04\n\x0eSearchUsersReq\x12\x10\n\x08username\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x12\n\nadmin_note\x18\x06 \x01(\t\x12\x0c\n\x04\x63ity\x18\x07 \x01(\t\x12\x13\n\x0bmin_user_id\x18\x08 \x01(\x03\x12\x13\n\x0bmax_user_id\x18\t \x01(\x03\x12\x15\n\rmin_birthdate\x18\n \x01(\t\x12\x15\n\rmax_birthdate\x18\x0b \x01(\t\x12\x17\n\x0fmin_joined_date\x18\x0c \x01(\t\x12\x17\n\x0fmax_joined_date\x18\r \x01(\t\x12\x1c\n\x14min_last_active_date\x18\x0e \x01(\t\x12\x1c\n\x14max_last_active_date\x18\x0f \x01(\t\x12\x0f\n\x07genders\x18\x10 \x03(\t\x12\x16\n\x0elanguage_codes\x18\x11 \x03(\t\x12.\n\nis_deleted\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\tis_banned\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\nhas_avatar\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"Y\n\x0eSearchUsersRes\x12.\n\x05users\x18\x01 \x03(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x13\x43hangeUserGenderReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06gender\x18\x02 \x01(\t\"9\n\x16\x43hangeUserBirthdateReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x11\n\tbirthdate\x18\x02 \x01(\t\"-\n\x0b\x41\x64\x64\x42\x61\x64geReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08\x62\x61\x64ge_id\x18\x02 \x01(\t\"0\n\x0eRemoveBadgeReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08\x62\x61\x64ge_id\x18\x02 \x01(\t\"W\n SetPassportSexGenderExceptionReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12%\n\x1dpassport_sex_gender_exception\x18\x02 \x01(\x08\".\n\nBanUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nadmin_note\x18\x02 \x01(\t\"0\n\x0cUnbanUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nadmin_note\x18\x02 \x01(\t\"3\n\x0f\x41\x64\x64\x41\x64minNoteReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x12\n\nadmin_note\x18\x02 \x01(\t\"\xe3\x01\n\rContentReport\x12\x19\n\x11\x63ontent_report_id\x18\x01 \x01(\x03\x12(\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11reporting_user_id\x18\x03 \x01(\x03\x12\x16\n\x0e\x61uthor_user_id\x18\x04 \x01(\x03\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x13\n\x0b\x63ontent_ref\x18\x07 \x01(\t\x12\x12\n\nuser_agent\x18\x08 \x01(\t\x12\x0c\n\x04page\x18\t \x01(\t\"0\n\x13GetContentReportReq\x12\x19\n\x11\x63ontent_report_id\x18\x01 \x01(\x03\"P\n\x13GetContentReportRes\x12\x39\n\x0e\x63ontent_report\x18\x01 \x01(\x0b\x32!.org.couchers.admin.ContentReport\"-\n\x1dGetContentReportsForAuthorReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"[\n\x1dGetContentReportsForAuthorRes\x12:\n\x0f\x63ontent_reports\x18\x01 \x03(\x0b\x32!.org.couchers.admin.ContentReport\"[\n\x0eSendModNoteReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x13\n\x0binternal_id\x18\x03 \x01(\t\x12\x15\n\rdo_not_notify\x18\x04 \x01(\x08\".\n\x1eMarkUserNeedsLocationUpdateReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1d\n\rDeleteUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"%\n\x15RecoverDeletedUserReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x1f\n\x0f\x43reateApiKeyReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x11\n\x0f\x43reateApiKeyRes\"\x1b\n\x0bGetChatsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"\xf5\x01\n\x0b\x43hatMessage\x12\x12\n\nmessage_id\x18\x01 \x01(\x03\x12/\n\x06\x61uthor\x18\x02 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cmessage_type\x18\x04 \x01(\t\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\"\n\x1ahost_request_status_target\x18\x06 \x01(\t\x12/\n\x06target\x18\x07 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\"\xa4\x01\n\x0fGroupChatMember\x12-\n\x04user\x18\x01 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12*\n\x06joined\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04left\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04role\x18\x04 \x01(\t\"\xe0\x01\n\x0e\x41\x64minGroupChat\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x03\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05is_dm\x18\x03 \x01(\x08\x12\x30\n\x07\x63reator\x18\x04 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12\x34\n\x07members\x18\x05 \x03(\x0b\x32#.org.couchers.admin.GroupChatMember\x12\x31\n\x08messages\x18\x06 \x03(\x0b\x32\x1f.org.couchers.admin.ChatMessage\"\x9f\x02\n\x10\x41\x64minHostRequest\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12/\n\x06surfer\x18\x02 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12-\n\x04host\x18\x03 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x11\n\tfrom_date\x18\x05 \x01(\t\x12\x0f\n\x07to_date\x18\x06 \x01(\t\x12+\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x08messages\x18\x08 \x03(\x0b\x32\x1f.org.couchers.admin.ChatMessage\"\xb2\x01\n\x0bGetChatsRes\x12-\n\x04user\x18\x01 \x01(\x0b\x32\x1f.org.couchers.admin.UserDetails\x12;\n\rhost_requests\x18\x02 \x03(\x0b\x32$.org.couchers.admin.AdminHostRequest\x12\x37\n\x0bgroup_chats\x18\x03 \x03(\x0b\x32\".org.couchers.admin.AdminGroupChat\"\"\n\x0e\x44\x65leteEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\"\x95\x01\n\x0eListUserIdsReq\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tpage_size\x18\x03 \x01(\r\x12\x12\n\npage_token\x18\x04 \x01(\t\";\n\x0eListUserIdsRes\x12\x10\n\x08user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\">\n\x14\x45\x64itReferenceTextReq\x12\x14\n\x0creference_id\x18\x01 \x01(\x03\x12\x10\n\x08new_text\x18\x02 \x01(\t\"*\n\x12\x44\x65leteReferenceReq\x12\x14\n\x0creference_id\x18\x01 \x01(\x03\"R\n\x11\x45\x64itDiscussionReq\x12\x15\n\rdiscussion_id\x18\x01 \x01(\x03\x12\x11\n\tnew_title\x18\x02 \x01(\t\x12\x13\n\x0bnew_content\x18\x03 \x01(\t\"5\n\x0c\x45\x64itReplyReq\x12\x10\n\x08reply_id\x18\x01 \x01(\x03\x12\x13\n\x0bnew_content\x18\x02 \x01(\t\"L\n\x1f\x41\x64\x64UsersToModerationUserListReq\x12\r\n\x05users\x18\x01 \x03(\t\x12\x1a\n\x12moderation_list_id\x18\x02 \x01(\x03\"*\n\x1aListModerationUserListsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\"@\n\x0eModerationList\x12\x1a\n\x12moderation_list_id\x18\x01 \x01(\x03\x12\x12\n\nmember_ids\x18\x02 \x03(\x03\"Z\n\x1aListModerationUserListsRes\x12<\n\x10moderation_lists\x18\x01 \x03(\x0b\x32\".org.couchers.admin.ModerationList\"=\n\x1f\x41\x64\x64UsersToModerationUserListRes\x12\x1a\n\x12moderation_list_id\x18\x01 \x01(\x03\"O\n#RemoveUserFromModerationUserListReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x1a\n\x12moderation_list_id\x18\x02 \x01(\x03\"A\n\x1c\x43reateAccountDeletionLinkReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x13\n\x0b\x65xpiry_days\x18\x02 \x01(\x03\"D\n\x1c\x43reateAccountDeletionLinkRes\x12$\n\x1c\x61\x63\x63ount_deletion_confirm_url\x18\x01 \x01(\t\"|\n\x0e\x41\x63\x63\x65ssStatsReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xca\x02\n\nAccessStat\x12\x12\n\nip_address\x18\x01 \x01(\t\x12\x0b\n\x03\x61sn\x18\x02 \x01(\t\x12\r\n\x05\x61sorg\x18\x03 \x01(\t\x12\x11\n\tasnetwork\x18\x04 \x01(\t\x12\x12\n\nuser_agent\x18\x05 \x01(\t\x12\x18\n\x10operating_system\x18\x06 \x01(\t\x12\x0f\n\x07\x62rowser\x18\x07 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x08 \x01(\t\x12\x1c\n\x14\x61pproximate_location\x18\t \x01(\t\x12\x16\n\x0e\x61pi_call_count\x18\n \x01(\x04\x12\x15\n\rperiods_count\x18\x0b \x01(\x04\x12.\n\nfirst_seen\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tlast_seen\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"?\n\x0e\x41\x63\x63\x65ssStatsRes\x12-\n\x05stats\x18\x01 \x03(\x0b\x32\x1e.org.couchers.admin.AccessStat\"S\n\x11SetLastDonatedReq\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x30\n\x0clast_donated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xb3\x17\n\x05\x41\x64min\x12Z\n\x0eGetUserDetails\x12%.org.couchers.admin.GetUserDetailsReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12H\n\x07GetUser\x12\x1e.org.couchers.admin.GetUserReq\x1a\x1b.org.couchers.api.core.User\"\x00\x12W\n\x0bSearchUsers\x12\".org.couchers.admin.SearchUsersReq\x1a\".org.couchers.admin.SearchUsersRes\"\x00\x12^\n\x10\x43hangeUserGender\x12\'.org.couchers.admin.ChangeUserGenderReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x64\n\x13\x43hangeUserBirthdate\x12*.org.couchers.admin.ChangeUserBirthdateReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12N\n\x08\x41\x64\x64\x42\x61\x64ge\x12\x1f.org.couchers.admin.AddBadgeReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12T\n\x0bRemoveBadge\x12\".org.couchers.admin.RemoveBadgeReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12x\n\x1dSetPassportSexGenderException\x12\x34.org.couchers.admin.SetPassportSexGenderExceptionReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12L\n\x07\x42\x61nUser\x12\x1e.org.couchers.admin.BanUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12P\n\tUnbanUser\x12 .org.couchers.admin.UnbanUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12V\n\x0c\x41\x64\x64\x41\x64minNote\x12#.org.couchers.admin.AddAdminNoteReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x66\n\x10GetContentReport\x12\'.org.couchers.admin.GetContentReportReq\x1a\'.org.couchers.admin.GetContentReportRes\"\x00\x12\x84\x01\n\x1aGetContentReportsForAuthor\x12\x31.org.couchers.admin.GetContentReportsForAuthorReq\x1a\x31.org.couchers.admin.GetContentReportsForAuthorRes\"\x00\x12T\n\x0bSendModNote\x12\".org.couchers.admin.SendModNoteReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12t\n\x1bMarkUserNeedsLocationUpdate\x12\x32.org.couchers.admin.MarkUserNeedsLocationUpdateReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12R\n\nDeleteUser\x12!.org.couchers.admin.DeleteUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12\x62\n\x12RecoverDeletedUser\x12).org.couchers.admin.RecoverDeletedUserReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x12Z\n\x0c\x43reateApiKey\x12#.org.couchers.admin.CreateApiKeyReq\x1a#.org.couchers.admin.CreateApiKeyRes\"\x00\x12N\n\x08GetChats\x12\x1f.org.couchers.admin.GetChatsReq\x1a\x1f.org.couchers.admin.GetChatsRes\"\x00\x12K\n\x0b\x44\x65leteEvent\x12\".org.couchers.admin.DeleteEventReq\x1a\x16.google.protobuf.Empty\"\x00\x12W\n\x0bListUserIds\x12\".org.couchers.admin.ListUserIdsReq\x1a\".org.couchers.admin.ListUserIdsRes\"\x00\x12W\n\x11\x45\x64itReferenceText\x12(.org.couchers.admin.EditReferenceTextReq\x1a\x16.google.protobuf.Empty\"\x00\x12S\n\x0f\x44\x65leteReference\x12&.org.couchers.admin.DeleteReferenceReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0e\x45\x64itDiscussion\x12%.org.couchers.admin.EditDiscussionReq\x1a\x16.google.protobuf.Empty\"\x00\x12G\n\tEditReply\x12 .org.couchers.admin.EditReplyReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x8a\x01\n\x1c\x41\x64\x64UsersToModerationUserList\x12\x33.org.couchers.admin.AddUsersToModerationUserListReq\x1a\x33.org.couchers.admin.AddUsersToModerationUserListRes\"\x00\x12u\n RemoveUserFromModerationUserList\x12\x37.org.couchers.admin.RemoveUserFromModerationUserListReq\x1a\x16.google.protobuf.Empty\"\x00\x12{\n\x17ListModerationUserLists\x12..org.couchers.admin.ListModerationUserListsReq\x1a..org.couchers.admin.ListModerationUserListsRes\"\x00\x12\x81\x01\n\x19\x43reateAccountDeletionLink\x12\x30.org.couchers.admin.CreateAccountDeletionLinkReq\x1a\x30.org.couchers.admin.CreateAccountDeletionLinkRes\"\x00\x12W\n\x0b\x41\x63\x63\x65ssStats\x12\".org.couchers.admin.AccessStatsReq\x1a\".org.couchers.admin.AccessStatsRes\"\x00\x12Z\n\x0eSetLastDonated\x12%.org.couchers.admin.SetLastDonatedReq\x1a\x1f.org.couchers.admin.UserDetails\"\x00\x1a\x04\x88\xb5\x18\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ADMIN']._loaded_options = None
  _globals['_ADMIN']._serialized_options = b'\210\265\030\004'
  _globals['_USERDETAILS']._serialized_start=160
  _globals['_USERDETAILS']._serialized_end=686
  _globals['_GETUSERDETAILSREQ']._serialized_start=688
  _globals['_GETUSERDETAILSREQ']._serialized_end=721
  _globals['_GETUSERREQ']._serialized_start=723
  _globals['_GETUSERREQ']._serialized_end=749
  _globals['_SEARCHUSERSREQ']._serialized_start=752
  _globals['_SEARCHUSERSREQ']._serialized_end=1270
  _globals['_SEARCHUSERSRES']._serialized_start=1272
  _globals['_SEARCHUSERSRES']._serialized_end=1361
  _globals['_CHANGEUSERGENDERREQ']._serialized_start=1363
  _globals['_CHANGEUSERGENDERREQ']._serialized_end=1414
  _globals['_CHANGEUSERBIRTHDATEREQ']._serialized_start=1416
  _globals['_CHANGEUSERBIRTHDATEREQ']._serialized_end=1473
  _globals['_ADDBADGEREQ']._serialized_start=1475
  _globals['_ADDBADGEREQ']._serialized_end=1520
  _globals['_REMOVEBADGEREQ']._serialized_start=1522
  _globals['_REMOVEBADGEREQ']._serialized_end=1570
  _globals['_SETPASSPORTSEXGENDEREXCEPTIONREQ']._serialized_start=1572
  _globals['_SETPASSPORTSEXGENDEREXCEPTIONREQ']._serialized_end=1659
  _globals['_BANUSERREQ']._serialized_start=1661
  _globals['_BANUSERREQ']._serialized_end=1707
  _globals['_UNBANUSERREQ']._serialized_start=1709
  _globals['_UNBANUSERREQ']._serialized_end=1757
  _globals['_ADDADMINNOTEREQ']._serialized_start=1759
  _globals['_ADDADMINNOTEREQ']._serialized_end=1810
  _globals['_CONTENTREPORT']._serialized_start=1813
  _globals['_CONTENTREPORT']._serialized_end=2040
  _globals['_GETCONTENTREPORTREQ']._serialized_start=2042
  _globals['_GETCONTENTREPORTREQ']._serialized_end=2090
  _globals['_GETCONTENTREPORTRES']._serialized_start=2092
  _globals['_GETCONTENTREPORTRES']._serialized_end=2172
  _globals['_GETCONTENTREPORTSFORAUTHORREQ']._serialized_start=2174
  _globals['_GETCONTENTREPORTSFORAUTHORREQ']._serialized_end=2219
  _globals['_GETCONTENTREPORTSFORAUTHORRES']._serialized_start=2221
  _globals['_GETCONTENTREPORTSFORAUTHORRES']._serialized_end=2312
  _globals['_SENDMODNOTEREQ']._serialized_start=2314
  _globals['_SENDMODNOTEREQ']._serialized_end=2405
  _globals['_MARKUSERNEEDSLOCATIONUPDATEREQ']._serialized_start=2407
  _globals['_MARKUSERNEEDSLOCATIONUPDATEREQ']._serialized_end=2453
  _globals['_DELETEUSERREQ']._serialized_start=2455
  _globals['_DELETEUSERREQ']._serialized_end=2484
  _globals['_RECOVERDELETEDUSERREQ']._serialized_start=2486
  _globals['_RECOVERDELETEDUSERREQ']._serialized_end=2523
  _globals['_CREATEAPIKEYREQ']._serialized_start=2525
  _globals['_CREATEAPIKEYREQ']._serialized_end=2556
  _globals['_CREATEAPIKEYRES']._serialized_start=2558
  _globals['_CREATEAPIKEYRES']._serialized_end=2575
  _globals['_GETCHATSREQ']._serialized_start=2577
  _globals['_GETCHATSREQ']._serialized_end=2604
  _globals['_CHATMESSAGE']._serialized_start=2607
  _globals['_CHATMESSAGE']._serialized_end=2852
  _globals['_GROUPCHATMEMBER']._serialized_start=2855
  _globals['_GROUPCHATMEMBER']._serialized_end=3019
  _globals['_ADMINGROUPCHAT']._serialized_start=3022
  _globals['_ADMINGROUPCHAT']._serialized_end=3246
  _globals['_ADMINHOSTREQUEST']._serialized_start=3249
  _globals['_ADMINHOSTREQUEST']._serialized_end=3536
  _globals['_GETCHATSRES']._serialized_start=3539
  _globals['_GETCHATSRES']._serialized_end=3717
  _globals['_DELETEEVENTREQ']._serialized_start=3719
  _globals['_DELETEEVENTREQ']._serialized_end=3753
  _globals['_LISTUSERIDSREQ']._serialized_start=3756
  _globals['_LISTUSERIDSREQ']._serialized_end=3905
  _globals['_LISTUSERIDSRES']._serialized_start=3907
  _globals['_LISTUSERIDSRES']._serialized_end=3966
  _globals['_EDITREFERENCETEXTREQ']._serialized_start=3968
  _globals['_EDITREFERENCETEXTREQ']._serialized_end=4030
  _globals['_DELETEREFERENCEREQ']._serialized_start=4032
  _globals['_DELETEREFERENCEREQ']._serialized_end=4074
  _globals['_EDITDISCUSSIONREQ']._serialized_start=4076
  _globals['_EDITDISCUSSIONREQ']._serialized_end=4158
  _globals['_EDITREPLYREQ']._serialized_start=4160
  _globals['_EDITREPLYREQ']._serialized_end=4213
  _globals['_ADDUSERSTOMODERATIONUSERLISTREQ']._serialized_start=4215
  _globals['_ADDUSERSTOMODERATIONUSERLISTREQ']._serialized_end=4291
  _globals['_LISTMODERATIONUSERLISTSREQ']._serialized_start=4293
  _globals['_LISTMODERATIONUSERLISTSREQ']._serialized_end=4335
  _globals['_MODERATIONLIST']._serialized_start=4337
  _globals['_MODERATIONLIST']._serialized_end=4401
  _globals['_LISTMODERATIONUSERLISTSRES']._serialized_start=4403
  _globals['_LISTMODERATIONUSERLISTSRES']._serialized_end=4493
  _globals['_ADDUSERSTOMODERATIONUSERLISTRES']._serialized_start=4495
  _globals['_ADDUSERSTOMODERATIONUSERLISTRES']._serialized_end=4556
  _globals['_REMOVEUSERFROMMODERATIONUSERLISTREQ']._serialized_start=4558
  _globals['_REMOVEUSERFROMMODERATIONUSERLISTREQ']._serialized_end=4637
  _globals['_CREATEACCOUNTDELETIONLINKREQ']._serialized_start=4639
  _globals['_CREATEACCOUNTDELETIONLINKREQ']._serialized_end=4704
  _globals['_CREATEACCOUNTDELETIONLINKRES']._serialized_start=4706
  _globals['_CREATEACCOUNTDELETIONLINKRES']._serialized_end=4774
  _globals['_ACCESSSTATSREQ']._serialized_start=4776
  _globals['_ACCESSSTATSREQ']._serialized_end=4900
  _globals['_ACCESSSTAT']._serialized_start=4903
  _globals['_ACCESSSTAT']._serialized_end=5233
  _globals['_ACCESSSTATSRES']._serialized_start=5235
  _globals['_ACCESSSTATSRES']._serialized_end=5298
  _globals['_SETLASTDONATEDREQ']._serialized_start=5300
  _globals['_SETLASTDONATEDREQ']._serialized_end=5383
  _globals['_ADMIN']._serialized_start=5386
  _globals['_ADMIN']._serialized_end=8381
# @@protoc_insertion_point(module_scope)
