from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import moderation_pb2
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class ModerationServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetModerationQueue(
        self,
        request: moderation_pb2.GetModerationQueueReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.GetModerationQueueRes, collections.abc.Awaitable[moderation_pb2.GetModerationQueueRes]]: ...

    @abc.abstractmethod
    def GetModerationState(
        self,
        request: moderation_pb2.GetModerationStateReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.GetModerationStateRes, collections.abc.Awaitable[moderation_pb2.GetModerationStateRes]]: ...

    @abc.abstractmethod
    def GetModerationLog(
        self,
        request: moderation_pb2.GetModerationLogReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.GetModerationLogRes, collections.abc.Awaitable[moderation_pb2.GetModerationLogRes]]: ...

    @abc.abstractmethod
    def ModerateContent(
        self,
        request: moderation_pb2.ModerateContentReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.ModerateContentRes, collections.abc.Awaitable[moderation_pb2.ModerateContentRes]]: ...

    @abc.abstractmethod
    def FlagContentForReview(
        self,
        request: moderation_pb2.FlagContentForReviewReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.FlagContentForReviewRes, collections.abc.Awaitable[moderation_pb2.FlagContentForReviewRes]]: ...

    @abc.abstractmethod
    def UnflagContent(
        self,
        request: moderation_pb2.UnflagContentReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[moderation_pb2.UnflagContentRes, collections.abc.Awaitable[moderation_pb2.UnflagContentRes]]: ...

def add_ModerationServicer_to_server(servicer: ModerationServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
