from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import account_pb2
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class AccountServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAccountInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetAccountInfoRes, collections.abc.Awaitable[account_pb2.GetAccountInfoRes]]:
        """account management APIs
        Get information about the user's account
        """

    @abc.abstractmethod
    def ChangePasswordV2(
        self,
        request: account_pb2.ChangePasswordV2Req,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Change the user's password
        we will send and an email to the user saying their password was changed
        """

    @abc.abstractmethod
    def ChangeEmailV2(
        self,
        request: account_pb2.ChangeEmailV2Req,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Change the user's email address
        We will send a notification email to the old email, and confirmation email to the new email
        Raises INVALID_ARGUMENT if password is too small, too large, insecure, wrong or not supplied.
        """

    @abc.abstractmethod
    def GetContributorFormInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetContributorFormInfoRes, collections.abc.Awaitable[account_pb2.GetContributorFormInfoRes]]:
        """Returns info related to filling out the contributor form"""

    @abc.abstractmethod
    def FillContributorForm(
        self,
        request: account_pb2.FillContributorFormReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Fill the contributor form; this can be done multiple times"""

    @abc.abstractmethod
    def ChangeLanguagePreference(
        self,
        request: account_pb2.ChangeLanguagePreferenceReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Changes the user's interface language"""

    @abc.abstractmethod
    def ChangePhone(
        self,
        request: account_pb2.ChangePhoneReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Set/Change/Remove phone number. An verification sms with a 6-digit code will be sent out,
        And returned in a call to in VerifyPhone() to complete the phone number change.
        An INVALID_ARGUMENT is returned if the phone number is not formatted according to E.164.
        A RESOURCE_EXHAUSTED error code indicates that you have done too many changes lately.
        An UNIMPLEMENTED error code indicates that sms to your operator is not supported.
        """

    @abc.abstractmethod
    def VerifyPhone(
        self,
        request: account_pb2.VerifyPhoneReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Enter the code you got in the sms. Other accounts using the same phone number will
        lose their verification status.
        """

    @abc.abstractmethod
    def InitiateStrongVerification(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.InitiateStrongVerificationRes, collections.abc.Awaitable[account_pb2.InitiateStrongVerificationRes]]:
        """Initiates a strong verification (passport read)"""

    @abc.abstractmethod
    def GetStrongVerificationAttemptStatus(
        self,
        request: account_pb2.GetStrongVerificationAttemptStatusReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetStrongVerificationAttemptStatusRes, collections.abc.Awaitable[account_pb2.GetStrongVerificationAttemptStatusRes]]:
        """Gets the status of a strong verification attempt"""

    @abc.abstractmethod
    def DeleteStrongVerificationData(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Deletes full SV data (but not minimal data), see the ToS"""

    @abc.abstractmethod
    def DeleteAccount(
        self,
        request: account_pb2.DeleteAccountReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Sends email with confirmation link containing token to delete account"""

    @abc.abstractmethod
    def ListModNotes(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.ListModNotesRes, collections.abc.Awaitable[account_pb2.ListModNotesRes]]:
        """Lists all the user's mod notes: only ack'd ones because otherwise the user is jailed"""

    @abc.abstractmethod
    def ListActiveSessions(
        self,
        request: account_pb2.ListActiveSessionsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.ListActiveSessionsRes, collections.abc.Awaitable[account_pb2.ListActiveSessionsRes]]:
        """Lists all the user's current sessions"""

    @abc.abstractmethod
    def LogOutSession(
        self,
        request: account_pb2.LogOutSessionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Logs the user out of the given session, cannot be current one"""

    @abc.abstractmethod
    def LogOutOtherSessions(
        self,
        request: account_pb2.LogOutOtherSessionsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Logs the user out of all other sessions except this one"""

    @abc.abstractmethod
    def SetProfilePublicVisibility(
        self,
        request: account_pb2.SetProfilePublicVisibilityReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Set what info is shown to logged-out users"""

    @abc.abstractmethod
    def CreateInviteCode(
        self,
        request: account_pb2.CreateInviteCodeReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.CreateInviteCodeRes, collections.abc.Awaitable[account_pb2.CreateInviteCodeRes]]:
        """Creates a new unique invite code for the current user"""

    @abc.abstractmethod
    def DisableInviteCode(
        self,
        request: account_pb2.DisableInviteCodeReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Disables the given invite code created by the user"""

    @abc.abstractmethod
    def ListInviteCodes(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.ListInviteCodesRes, collections.abc.Awaitable[account_pb2.ListInviteCodesRes]]:
        """Lists all invite codes created by the user, with usage count"""

    @abc.abstractmethod
    def GetReminders(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetRemindersRes, collections.abc.Awaitable[account_pb2.GetRemindersRes]]:
        """Reminders to be shown on dashboard for things the user should do"""

    @abc.abstractmethod
    def GetMyVolunteerInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetMyVolunteerInfoRes, collections.abc.Awaitable[account_pb2.GetMyVolunteerInfoRes]]:
        """Returns info about the current user's volunteer status if they are volunteer"""

    @abc.abstractmethod
    def UpdateMyVolunteerInfo(
        self,
        request: account_pb2.UpdateMyVolunteerInfoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[account_pb2.GetMyVolunteerInfoRes, collections.abc.Awaitable[account_pb2.GetMyVolunteerInfoRes]]:
        """Updates the current user's volunteer status if they are volunteer"""

def add_AccountServicer_to_server(servicer: AccountServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
