# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bugs.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from .google.api import httpbody_pb2 as google_dot_api_dot_httpbody__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nbugs.proto\x12\x11org.couchers.bugs\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/api/httpbody.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"\x1e\n\x0bVersionInfo\x12\x0f\n\x07version\x18\x01 \x01(\t\"1\n\x10ScreenResolution\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\"\xc1\x01\n\x0cReportBugReq\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07results\x18\x04 \x01(\t\x12\x18\n\x10\x66rontend_version\x18\x05 \x01(\t\x12\x12\n\nuser_agent\x18\x06 \x01(\t\x12\x0c\n\x04page\x18\x07 \x01(\t\x12>\n\x11screen_resolution\x18\x08 \x01(\x0b\x32#.org.couchers.bugs.ScreenResolution\"/\n\x0cReportBugRes\x12\x0e\n\x06\x62ug_id\x18\x02 \x01(\t\x12\x0f\n\x07\x62ug_url\x18\x03 \x01(\t\"\x1a\n\tStatusReq\x12\r\n\x05nonce\x18\x01 \x01(\t\"B\n\tStatusRes\x12\r\n\x05nonce\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x15\n\rcoucher_count\x18\x03 \x01(\x04\"\x84\x01\n\x18GeolocationSearchInfoReq\x12\x15\n\rsearch_string\x18\x01 \x01(\t\x12\x1d\n\x15nominatim_result_json\x18\x02 \x01(\t\x12\x1d\n\x15\x66ormatted_result_json\x18\x03 \x01(\t\x12\x13\n\x0b\x64uration_ms\x18\x04 \x01(\r\"e\n\x17GeolocationClickInfoReq\x12\x0f\n\x07\x63ontext\x18\x01 \x01(\t\x12\x1d\n\x15\x66ormatted_result_json\x18\x02 \x01(\t\x12\x1a\n\x12search_choice_json\x18\x03 \x01(\t2\xa0\x04\n\x04\x42ugs\x12S\n\x07Version\x12\x16.google.protobuf.Empty\x1a\x1e.org.couchers.bugs.VersionInfo\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/version\x12O\n\tReportBug\x12\x1f.org.couchers.bugs.ReportBugReq\x1a\x1f.org.couchers.bugs.ReportBugRes\"\x00\x12U\n\x06Status\x12\x1c.org.couchers.bugs.StatusReq\x1a\x1c.org.couchers.bugs.StatusRes\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/status\x12W\n\x0eGetDescriptors\x12\x16.google.protobuf.Empty\x1a\x14.google.api.HttpBody\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/descriptors.pb\x12^\n\x15GeolocationSearchInfo\x12+.org.couchers.bugs.GeolocationSearchInfoReq\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x14GeolocationClickInfo\x12*.org.couchers.bugs.GeolocationClickInfoReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bugs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BUGS']._loaded_options = None
  _globals['_BUGS']._serialized_options = b'\210\265\030\001'
  _globals['_BUGS'].methods_by_name['Version']._loaded_options = None
  _globals['_BUGS'].methods_by_name['Version']._serialized_options = b'\202\323\344\223\002\n\022\010/version'
  _globals['_BUGS'].methods_by_name['Status']._loaded_options = None
  _globals['_BUGS'].methods_by_name['Status']._serialized_options = b'\202\323\344\223\002\t\022\007/status'
  _globals['_BUGS'].methods_by_name['GetDescriptors']._loaded_options = None
  _globals['_BUGS'].methods_by_name['GetDescriptors']._serialized_options = b'\202\323\344\223\002\021\022\017/descriptors.pb'
  _globals['_VERSIONINFO']._serialized_start=138
  _globals['_VERSIONINFO']._serialized_end=168
  _globals['_SCREENRESOLUTION']._serialized_start=170
  _globals['_SCREENRESOLUTION']._serialized_end=219
  _globals['_REPORTBUGREQ']._serialized_start=222
  _globals['_REPORTBUGREQ']._serialized_end=415
  _globals['_REPORTBUGRES']._serialized_start=417
  _globals['_REPORTBUGRES']._serialized_end=464
  _globals['_STATUSREQ']._serialized_start=466
  _globals['_STATUSREQ']._serialized_end=492
  _globals['_STATUSRES']._serialized_start=494
  _globals['_STATUSRES']._serialized_end=560
  _globals['_GEOLOCATIONSEARCHINFOREQ']._serialized_start=563
  _globals['_GEOLOCATIONSEARCHINFOREQ']._serialized_end=695
  _globals['_GEOLOCATIONCLICKINFOREQ']._serialized_start=697
  _globals['_GEOLOCATIONCLICKINFOREQ']._serialized_end=798
  _globals['_BUGS']._serialized_start=801
  _globals['_BUGS']._serialized_end=1345
# @@protoc_insertion_point(module_scope)
