# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import feature_suggestions_pb2 as feature__suggestions__pb2


class FeatureSuggestionsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFeatureSuggestions = channel.unary_unary(
                '/org.couchers.api.feature_suggestions.FeatureSuggestions/ListFeatureSuggestions',
                request_serializer=feature__suggestions__pb2.ListFeatureSuggestionsReq.SerializeToString,
                response_deserializer=feature__suggestions__pb2.ListFeatureSuggestionsRes.FromString,
                )
        self.CreateFeatureSuggestion = channel.unary_unary(
                '/org.couchers.api.feature_suggestions.FeatureSuggestions/CreateFeatureSuggestion',
                request_serializer=feature__suggestions__pb2.CreateFeatureSuggestionReq.SerializeToString,
                response_deserializer=feature__suggestions__pb2.FeatureSuggestion.FromString,
                )
        self.VoteOnFeatureSuggestion = channel.unary_unary(
                '/org.couchers.api.feature_suggestions.FeatureSuggestions/VoteOnFeatureSuggestion',
                request_serializer=feature__suggestions__pb2.VoteOnFeatureSuggestionReq.SerializeToString,
                response_deserializer=feature__suggestions__pb2.FeatureSuggestion.FromString,
                )


class FeatureSuggestionsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFeatureSuggestions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeatureSuggestion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VoteOnFeatureSuggestion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureSuggestionsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFeatureSuggestions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureSuggestions,
                    request_deserializer=feature__suggestions__pb2.ListFeatureSuggestionsReq.FromString,
                    response_serializer=feature__suggestions__pb2.ListFeatureSuggestionsRes.SerializeToString,
            ),
            'CreateFeatureSuggestion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeatureSuggestion,
                    request_deserializer=feature__suggestions__pb2.CreateFeatureSuggestionReq.FromString,
                    response_serializer=feature__suggestions__pb2.FeatureSuggestion.SerializeToString,
            ),
            'VoteOnFeatureSuggestion': grpc.unary_unary_rpc_method_handler(
                    servicer.VoteOnFeatureSuggestion,
                    request_deserializer=feature__suggestions__pb2.VoteOnFeatureSuggestionReq.FromString,
                    response_serializer=feature__suggestions__pb2.FeatureSuggestion.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.feature_suggestions.FeatureSuggestions', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureSuggestions(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFeatureSuggestions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.feature_suggestions.FeatureSuggestions/ListFeatureSuggestions',
            feature__suggestions__pb2.ListFeatureSuggestionsReq.SerializeToString,
            feature__suggestions__pb2.ListFeatureSuggestionsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeatureSuggestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.feature_suggestions.FeatureSuggestions/CreateFeatureSuggestion',
            feature__suggestions__pb2.CreateFeatureSuggestionReq.SerializeToString,
            feature__suggestions__pb2.FeatureSuggestion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VoteOnFeatureSuggestion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.feature_suggestions.FeatureSuggestions/VoteOnFeatureSuggestion',
            feature__suggestions__pb2.VoteOnFeatureSuggestionReq.SerializeToString,
            feature__suggestions__pb2.FeatureSuggestion.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
