# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: account.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2
from . import auth_pb2 as auth__pb2
from . import references_pb2 as references__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\raccount.proto\x12\x18org.couchers.api.account\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\x1a\nauth.proto\x1a\x10references.proto\"\xe4\x04\n\x11GetAccountInfoRes\x12\x10\n\x08username\x18\x07 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x18\n\x10profile_complete\x18\x04 \x01(\x08\x12\x18\n\x10my_home_complete\x18\x13 \x01(\x08\x12\r\n\x05phone\x18\x08 \x01(\t\x12\x16\n\x0ephone_verified\x18\t \x01(\x08\x12\x10\n\x08timezone\x18\x06 \x01(\t\x12\x13\n\x0bhas_donated\x18\x0e \x01(\x08\x12\x1f\n\x17has_strong_verification\x18\n \x01(\x08\x12Y\n\x1d\x62irthdate_verification_status\x18\x0b \x01(\x0e\x32\x32.org.couchers.api.core.BirthdateVerificationStatus\x12S\n\x1agender_verification_status\x18\x0c \x01(\x0e\x32/.org.couchers.api.core.GenderVerificationStatus\x12\x14\n\x0c\x64o_not_email\x18\r \x01(\x08\x12\x14\n\x0cis_superuser\x18\x0f \x01(\x08\x12\x1e\n\x16ui_language_preference\x18\x10 \x01(\t\x12T\n\x19profile_public_visibility\x18\x11 \x01(\x0e\x32\x31.org.couchers.api.account.ProfilePublicVisibility\x12\x14\n\x0cis_volunteer\x18\x12 \x01(\x08\x12#\n\x1bshould_show_donation_banner\x18\x14 \x01(\x08\"M\n\x13\x43hangePasswordV2Req\x12\x1a\n\x0cold_password\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12\x1a\n\x0cnew_password\x18\x02 \x01(\tB\x04\x80\xb5\x18\x01\"=\n\x10\x43hangeEmailV2Req\x12\x16\n\x08password\x18\x01 \x01(\tB\x04\x80\xb5\x18\x01\x12\x11\n\tnew_email\x18\x02 \x01(\t\"=\n\x1b\x43hangeLanguagePreferenceReq\x12\x1e\n\x16ui_language_preference\x18\x01 \x01(\t\"<\n\x19GetContributorFormInfoRes\x12\x1f\n\x17\x66illed_contributor_form\x18\x01 \x01(\x08\"V\n\x16\x46illContributorFormReq\x12<\n\x10\x63ontributor_form\x18\x01 \x01(\x0b\x32\".org.couchers.auth.ContributorForm\"\x1f\n\x0e\x43hangePhoneReq\x12\r\n\x05phone\x18\x01 \x01(\t\"%\n\x0eVerifyPhoneReq\x12\x13\n\x05token\x18\x01 \x01(\tB\x04\x88\xb5\x18\x01\"Y\n\x1dInitiateStrongVerificationRes\x12\"\n\x1averification_attempt_token\x18\x01 \x01(\t\x12\x14\n\x0credirect_url\x18\x03 \x01(\t\"K\n%GetStrongVerificationAttemptStatusReq\x12\"\n\x1averification_attempt_token\x18\x01 \x01(\t\"r\n%GetStrongVerificationAttemptStatusRes\x12I\n\x06status\x18\x01 \x01(\x0e\x32\x39.org.couchers.api.account.StrongVerificationAttemptStatus\"3\n\x10\x44\x65leteAccountReq\x12\x0f\n\x07\x63onfirm\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x8f\x01\n\x07ModNote\x12\x0f\n\x07note_id\x18\x01 \x01(\x04\x12\x14\n\x0cnote_content\x18\x02 \x01(\t\x12+\n\x07\x63reated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x61\x63knowledged\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"G\n\x0fListModNotesRes\x12\x34\n\tmod_notes\x18\x01 \x03(\x0b\x32!.org.couchers.api.account.ModNote\">\n\x15ListActiveSessionsReq\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"\x8c\x02\n\rActiveSession\x12+\n\x07\x63reated\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65xpiry\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tlast_seen\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10operating_system\x18\x04 \x01(\t\x12\x0f\n\x07\x62rowser\x18\x05 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x06 \x01(\t\x12\x1c\n\x14\x61pproximate_location\x18\x07 \x01(\t\x12\x1a\n\x12is_current_session\x18\x08 \x01(\x08\"r\n\x15ListActiveSessionsRes\x12@\n\x0f\x61\x63tive_sessions\x18\x01 \x03(\x0b\x32\'.org.couchers.api.account.ActiveSession\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"?\n\x10LogOutSessionReq\x12+\n\x07\x63reated\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\")\n\x16LogOutOtherSessionsReq\x12\x0f\n\x07\x63onfirm\x18\x01 \x01(\x08\"u\n\x1dSetProfilePublicVisibilityReq\x12T\n\x19profile_public_visibility\x18\x01 \x01(\x0e\x32\x31.org.couchers.api.account.ProfilePublicVisibility\"\x15\n\x13\x43reateInviteCodeReq\"0\n\x13\x43reateInviteCodeRes\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"$\n\x14\x44isableInviteCodeReq\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\"\x94\x01\n\x0eInviteCodeInfo\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12+\n\x07\x63reated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x64isabled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04uses\x18\x04 \x01(\x05\x12\x0b\n\x03url\x18\x05 \x01(\t\"T\n\x12ListInviteCodesRes\x12>\n\x0cinvite_codes\x18\x01 \x03(\x0b\x32(.org.couchers.api.account.InviteCodeInfo\"\x19\n\x17\x43ompleteProfileReminder\"\x1e\n\x1c\x43ompleteVerificationReminder\"m\n\x1cRespondToHostRequestReminder\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x34\n\x0bsurfer_user\x18\x02 \x01(\x0b\x32\x1f.org.couchers.api.core.LiteUser\"\xaa\x01\n\x16WriteReferenceReminder\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12\x33\n\nother_user\x18\x02 \x01(\x0b\x32\x1f.org.couchers.api.core.LiteUser\x12\x42\n\x0ereference_type\x18\x03 \x01(\x0e\x32*.org.couchers.api.references.ReferenceType\"\x8a\x03\n\x08Reminder\x12V\n\x19\x63omplete_profile_reminder\x18\x01 \x01(\x0b\x32\x31.org.couchers.api.account.CompleteProfileReminderH\x00\x12`\n\x1e\x63omplete_verification_reminder\x18\x02 \x01(\x0b\x32\x36.org.couchers.api.account.CompleteVerificationReminderH\x00\x12\x62\n respond_to_host_request_reminder\x18\x03 \x01(\x0b\x32\x36.org.couchers.api.account.RespondToHostRequestReminderH\x00\x12T\n\x18write_reference_reminder\x18\x04 \x01(\x0b\x32\x30.org.couchers.api.account.WriteReferenceReminderH\x00\x42\n\n\x08reminder\"H\n\x0fGetRemindersRes\x12\x35\n\treminders\x18\x01 \x03(\x0b\x32\".org.couchers.api.account.Reminder\"\xe4\x01\n\x15GetMyVolunteerInfoRes\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\x18\n\x10\x64isplay_location\x18\x02 \x01(\t\x12\x0c\n\x04role\x18\x03 \x01(\t\x12\x1c\n\x14started_volunteering\x18\x04 \x01(\t\x12\x1c\n\x14stopped_volunteering\x18\x05 \x01(\t\x12\x19\n\x11show_on_team_page\x18\x06 \x01(\x08\x12\x11\n\tlink_type\x18\x07 \x01(\t\x12\x11\n\tlink_text\x18\x08 \x01(\t\x12\x10\n\x08link_url\x18\t \x01(\t\"\xcf\x02\n\x18UpdateMyVolunteerInfoReq\x12\x32\n\x0c\x64isplay_name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10\x64isplay_location\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x11show_on_team_page\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\tlink_type\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tlink_text\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08link_url\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue*\x94\x03\n\x1fStrongVerificationAttemptStatus\x12.\n*STRONG_VERIFICATION_ATTEMPT_STATUS_UNKNOWN\x10\x00\x12\x30\n,STRONG_VERIFICATION_ATTEMPT_STATUS_SUCCEEDED\x10\x01\x12N\nJSTRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_USER_TO_OPEN_APP\x10\x02\x12I\nESTRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_USER_IN_APP\x10\x05\x12\x45\nASTRONG_VERIFICATION_ATTEMPT_STATUS_IN_PROGRESS_WAITING_ON_BACKEND\x10\x03\x12-\n)STRONG_VERIFICATION_ATTEMPT_STATUS_FAILED\x10\x04*\xfe\x01\n\x17ProfilePublicVisibility\x12%\n!PROFILE_PUBLIC_VISIBILITY_UNKNOWN\x10\x00\x12%\n!PROFILE_PUBLIC_VISIBILITY_NOTHING\x10\x01\x12&\n\"PROFILE_PUBLIC_VISIBILITY_MAP_ONLY\x10\x02\x12%\n!PROFILE_PUBLIC_VISIBILITY_LIMITED\x10\x03\x12\"\n\x1ePROFILE_PUBLIC_VISIBILITY_MOST\x10\x04\x12\"\n\x1ePROFILE_PUBLIC_VISIBILITY_FULL\x10\x05\x32\x9e\x12\n\x07\x41\x63\x63ount\x12W\n\x0eGetAccountInfo\x12\x16.google.protobuf.Empty\x1a+.org.couchers.api.account.GetAccountInfoRes\"\x00\x12[\n\x10\x43hangePasswordV2\x12-.org.couchers.api.account.ChangePasswordV2Req\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\rChangeEmailV2\x12*.org.couchers.api.account.ChangeEmailV2Req\x1a\x16.google.protobuf.Empty\"\x00\x12g\n\x16GetContributorFormInfo\x12\x16.google.protobuf.Empty\x1a\x33.org.couchers.api.account.GetContributorFormInfoRes\"\x00\x12\x61\n\x13\x46illContributorForm\x12\x30.org.couchers.api.account.FillContributorFormReq\x1a\x16.google.protobuf.Empty\"\x00\x12k\n\x18\x43hangeLanguagePreference\x12\x35.org.couchers.api.account.ChangeLanguagePreferenceReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0b\x43hangePhone\x12(.org.couchers.api.account.ChangePhoneReq\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x0bVerifyPhone\x12(.org.couchers.api.account.VerifyPhoneReq\x1a\x16.google.protobuf.Empty\"\x00\x12o\n\x1aInitiateStrongVerification\x12\x16.google.protobuf.Empty\x1a\x37.org.couchers.api.account.InitiateStrongVerificationRes\"\x00\x12\xa8\x01\n\"GetStrongVerificationAttemptStatus\x12?.org.couchers.api.account.GetStrongVerificationAttemptStatusReq\x1a?.org.couchers.api.account.GetStrongVerificationAttemptStatusRes\"\x00\x12P\n\x1c\x44\x65leteStrongVerificationData\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\rDeleteAccount\x12*.org.couchers.api.account.DeleteAccountReq\x1a\x16.google.protobuf.Empty\"\x00\x12S\n\x0cListModNotes\x12\x16.google.protobuf.Empty\x1a).org.couchers.api.account.ListModNotesRes\"\x00\x12x\n\x12ListActiveSessions\x12/.org.couchers.api.account.ListActiveSessionsReq\x1a/.org.couchers.api.account.ListActiveSessionsRes\"\x00\x12U\n\rLogOutSession\x12*.org.couchers.api.account.LogOutSessionReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x61\n\x13LogOutOtherSessions\x12\x30.org.couchers.api.account.LogOutOtherSessionsReq\x1a\x16.google.protobuf.Empty\"\x00\x12o\n\x1aSetProfilePublicVisibility\x12\x37.org.couchers.api.account.SetProfilePublicVisibilityReq\x1a\x16.google.protobuf.Empty\"\x00\x12r\n\x10\x43reateInviteCode\x12-.org.couchers.api.account.CreateInviteCodeReq\x1a-.org.couchers.api.account.CreateInviteCodeRes\"\x00\x12]\n\x11\x44isableInviteCode\x12..org.couchers.api.account.DisableInviteCodeReq\x1a\x16.google.protobuf.Empty\"\x00\x12Y\n\x0fListInviteCodes\x12\x16.google.protobuf.Empty\x1a,.org.couchers.api.account.ListInviteCodesRes\"\x00\x12S\n\x0cGetReminders\x12\x16.google.protobuf.Empty\x1a).org.couchers.api.account.GetRemindersRes\"\x00\x12_\n\x12GetMyVolunteerInfo\x12\x16.google.protobuf.Empty\x1a/.org.couchers.api.account.GetMyVolunteerInfoRes\"\x00\x12~\n\x15UpdateMyVolunteerInfo\x12\x32.org.couchers.api.account.UpdateMyVolunteerInfoReq\x1a/.org.couchers.api.account.GetMyVolunteerInfoRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHANGEPASSWORDV2REQ'].fields_by_name['old_password']._loaded_options = None
  _globals['_CHANGEPASSWORDV2REQ'].fields_by_name['old_password']._serialized_options = b'\200\265\030\001'
  _globals['_CHANGEPASSWORDV2REQ'].fields_by_name['new_password']._loaded_options = None
  _globals['_CHANGEPASSWORDV2REQ'].fields_by_name['new_password']._serialized_options = b'\200\265\030\001'
  _globals['_CHANGEEMAILV2REQ'].fields_by_name['password']._loaded_options = None
  _globals['_CHANGEEMAILV2REQ'].fields_by_name['password']._serialized_options = b'\200\265\030\001'
  _globals['_VERIFYPHONEREQ'].fields_by_name['token']._loaded_options = None
  _globals['_VERIFYPHONEREQ'].fields_by_name['token']._serialized_options = b'\210\265\030\001'
  _globals['_ACCOUNT']._loaded_options = None
  _globals['_ACCOUNT']._serialized_options = b'\210\265\030\003'
  _globals['_STRONGVERIFICATIONATTEMPTSTATUS']._serialized_start=4205
  _globals['_STRONGVERIFICATIONATTEMPTSTATUS']._serialized_end=4609
  _globals['_PROFILEPUBLICVISIBILITY']._serialized_start=4612
  _globals['_PROFILEPUBLICVISIBILITY']._serialized_end=4866
  _globals['_GETACCOUNTINFORES']._serialized_start=198
  _globals['_GETACCOUNTINFORES']._serialized_end=810
  _globals['_CHANGEPASSWORDV2REQ']._serialized_start=812
  _globals['_CHANGEPASSWORDV2REQ']._serialized_end=889
  _globals['_CHANGEEMAILV2REQ']._serialized_start=891
  _globals['_CHANGEEMAILV2REQ']._serialized_end=952
  _globals['_CHANGELANGUAGEPREFERENCEREQ']._serialized_start=954
  _globals['_CHANGELANGUAGEPREFERENCEREQ']._serialized_end=1015
  _globals['_GETCONTRIBUTORFORMINFORES']._serialized_start=1017
  _globals['_GETCONTRIBUTORFORMINFORES']._serialized_end=1077
  _globals['_FILLCONTRIBUTORFORMREQ']._serialized_start=1079
  _globals['_FILLCONTRIBUTORFORMREQ']._serialized_end=1165
  _globals['_CHANGEPHONEREQ']._serialized_start=1167
  _globals['_CHANGEPHONEREQ']._serialized_end=1198
  _globals['_VERIFYPHONEREQ']._serialized_start=1200
  _globals['_VERIFYPHONEREQ']._serialized_end=1237
  _globals['_INITIATESTRONGVERIFICATIONRES']._serialized_start=1239
  _globals['_INITIATESTRONGVERIFICATIONRES']._serialized_end=1328
  _globals['_GETSTRONGVERIFICATIONATTEMPTSTATUSREQ']._serialized_start=1330
  _globals['_GETSTRONGVERIFICATIONATTEMPTSTATUSREQ']._serialized_end=1405
  _globals['_GETSTRONGVERIFICATIONATTEMPTSTATUSRES']._serialized_start=1407
  _globals['_GETSTRONGVERIFICATIONATTEMPTSTATUSRES']._serialized_end=1521
  _globals['_DELETEACCOUNTREQ']._serialized_start=1523
  _globals['_DELETEACCOUNTREQ']._serialized_end=1574
  _globals['_MODNOTE']._serialized_start=1577
  _globals['_MODNOTE']._serialized_end=1720
  _globals['_LISTMODNOTESRES']._serialized_start=1722
  _globals['_LISTMODNOTESRES']._serialized_end=1793
  _globals['_LISTACTIVESESSIONSREQ']._serialized_start=1795
  _globals['_LISTACTIVESESSIONSREQ']._serialized_end=1857
  _globals['_ACTIVESESSION']._serialized_start=1860
  _globals['_ACTIVESESSION']._serialized_end=2128
  _globals['_LISTACTIVESESSIONSRES']._serialized_start=2130
  _globals['_LISTACTIVESESSIONSRES']._serialized_end=2244
  _globals['_LOGOUTSESSIONREQ']._serialized_start=2246
  _globals['_LOGOUTSESSIONREQ']._serialized_end=2309
  _globals['_LOGOUTOTHERSESSIONSREQ']._serialized_start=2311
  _globals['_LOGOUTOTHERSESSIONSREQ']._serialized_end=2352
  _globals['_SETPROFILEPUBLICVISIBILITYREQ']._serialized_start=2354
  _globals['_SETPROFILEPUBLICVISIBILITYREQ']._serialized_end=2471
  _globals['_CREATEINVITECODEREQ']._serialized_start=2473
  _globals['_CREATEINVITECODEREQ']._serialized_end=2494
  _globals['_CREATEINVITECODERES']._serialized_start=2496
  _globals['_CREATEINVITECODERES']._serialized_end=2544
  _globals['_DISABLEINVITECODEREQ']._serialized_start=2546
  _globals['_DISABLEINVITECODEREQ']._serialized_end=2582
  _globals['_INVITECODEINFO']._serialized_start=2585
  _globals['_INVITECODEINFO']._serialized_end=2733
  _globals['_LISTINVITECODESRES']._serialized_start=2735
  _globals['_LISTINVITECODESRES']._serialized_end=2819
  _globals['_COMPLETEPROFILEREMINDER']._serialized_start=2821
  _globals['_COMPLETEPROFILEREMINDER']._serialized_end=2846
  _globals['_COMPLETEVERIFICATIONREMINDER']._serialized_start=2848
  _globals['_COMPLETEVERIFICATIONREMINDER']._serialized_end=2878
  _globals['_RESPONDTOHOSTREQUESTREMINDER']._serialized_start=2880
  _globals['_RESPONDTOHOSTREQUESTREMINDER']._serialized_end=2989
  _globals['_WRITEREFERENCEREMINDER']._serialized_start=2992
  _globals['_WRITEREFERENCEREMINDER']._serialized_end=3162
  _globals['_REMINDER']._serialized_start=3165
  _globals['_REMINDER']._serialized_end=3559
  _globals['_GETREMINDERSRES']._serialized_start=3561
  _globals['_GETREMINDERSRES']._serialized_end=3633
  _globals['_GETMYVOLUNTEERINFORES']._serialized_start=3636
  _globals['_GETMYVOLUNTEERINFORES']._serialized_end=3864
  _globals['_UPDATEMYVOLUNTEERINFOREQ']._serialized_start=3867
  _globals['_UPDATEMYVOLUNTEERINFOREQ']._serialized_end=4202
  _globals['_ACCOUNT']._serialized_start=4869
  _globals['_ACCOUNT']._serialized_end=7203
# @@protoc_insertion_point(module_scope)
