# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: moderation.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10moderation.proto\x12\x17org.couchers.moderation\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"\xa6\x02\n\x13ModerationStateInfo\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\x12\x42\n\x0bobject_type\x18\x02 \x01(\x0e\x32-.org.couchers.moderation.ModerationObjectType\x12\x11\n\tobject_id\x18\x03 \x01(\x03\x12\x41\n\nvisibility\x18\x04 \x01(\x0e\x32-.org.couchers.moderation.ModerationVisibility\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07updated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xe2\x02\n\x17ModerationQueueItemInfo\x12\x15\n\rqueue_item_id\x18\x01 \x01(\x03\x12\x1b\n\x13moderation_state_id\x18\x02 \x01(\x03\x12\x30\n\x0ctime_created\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x07trigger\x18\x04 \x01(\x0e\x32*.org.couchers.moderation.ModerationTrigger\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x1b\n\x13item_author_user_id\x18\x06 \x01(\x03\x12\x13\n\x0bis_resolved\x18\x07 \x01(\x08\x12\x1a\n\x12resolved_by_log_id\x18\x08 \x01(\x03\x12\x46\n\x10moderation_state\x18\t \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\"\xa2\x02\n\x16ModerationLogEntryInfo\x12\x14\n\x0clog_entry_id\x18\x01 \x01(\x03\x12\x1b\n\x13moderation_state_id\x18\x02 \x01(\x03\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32).org.couchers.moderation.ModerationAction\x12\x19\n\x11moderator_user_id\x18\x05 \x01(\x03\x12\x45\n\x0enew_visibility\x18\x06 \x01(\x0e\x32-.org.couchers.moderation.ModerationVisibility\x12\x0e\n\x06reason\x18\x07 \x01(\t\"\xf3\x02\n\x15GetModerationQueueReq\x12<\n\x08triggers\x18\x04 \x03(\x0e\x32*.org.couchers.moderation.ModerationTrigger\x12\x42\n\x0bobject_type\x18\x05 \x01(\x0e\x32-.org.couchers.moderation.ModerationObjectType\x12\x17\n\x0funresolved_only\x18\x06 \x01(\x08\x12\x32\n\x0e\x63reated_before\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rcreated_after\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13item_author_user_id\x18\t \x01(\x03\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x14\n\x0cnewest_first\x18\x03 \x01(\x08\"w\n\x15GetModerationQueueRes\x12\x45\n\x0bqueue_items\x18\x01 \x03(\x0b\x32\x30.org.couchers.moderation.ModerationQueueItemInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"n\n\x15GetModerationStateReq\x12\x42\n\x0bobject_type\x18\x01 \x01(\x0e\x32-.org.couchers.moderation.ModerationObjectType\x12\x11\n\tobject_id\x18\x02 \x01(\x03\"_\n\x15GetModerationStateRes\x12\x46\n\x10moderation_state\x18\x01 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\"2\n\x13GetModerationLogReq\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\"\xa3\x01\n\x13GetModerationLogRes\x12\x44\n\x0blog_entries\x18\x01 \x03(\x0b\x32/.org.couchers.moderation.ModerationLogEntryInfo\x12\x46\n\x10moderation_state\x18\x02 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\"\xbf\x01\n\x12ModerateContentReq\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\x12\x39\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32).org.couchers.moderation.ModerationAction\x12\x41\n\nvisibility\x18\x03 \x01(\x0e\x32-.org.couchers.moderation.ModerationVisibility\x12\x0e\n\x06reason\x18\x04 \x01(\t\"\\\n\x12ModerateContentRes\x12\x46\n\x10moderation_state\x18\x01 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo\"\x83\x01\n\x17\x46lagContentForReviewReq\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\x12;\n\x07trigger\x18\x02 \x01(\x0e\x32*.org.couchers.moderation.ModerationTrigger\x12\x0e\n\x06reason\x18\x03 \x01(\t\"_\n\x17\x46lagContentForReviewRes\x12\x44\n\nqueue_item\x18\x01 \x01(\x0b\x32\x30.org.couchers.moderation.ModerationQueueItemInfo\"?\n\x10UnflagContentReq\x12\x1b\n\x13moderation_state_id\x18\x01 \x01(\x03\x12\x0e\n\x06reason\x18\x02 \x01(\t\"Z\n\x10UnflagContentRes\x12\x46\n\x10moderation_state\x18\x01 \x01(\x0b\x32,.org.couchers.moderation.ModerationStateInfo*\xca\x01\n\x14ModerationVisibility\x12%\n!MODERATION_VISIBILITY_UNSPECIFIED\x10\x00\x12 \n\x1cMODERATION_VISIBILITY_HIDDEN\x10\x01\x12\"\n\x1eMODERATION_VISIBILITY_SHADOWED\x10\x02\x12!\n\x1dMODERATION_VISIBILITY_VISIBLE\x10\x03\x12\"\n\x1eMODERATION_VISIBILITY_UNLISTED\x10\x04*\xce\x01\n\x11ModerationTrigger\x12\"\n\x1eMODERATION_TRIGGER_UNSPECIFIED\x10\x00\x12%\n!MODERATION_TRIGGER_INITIAL_REVIEW\x10\x01\x12 \n\x1cMODERATION_TRIGGER_USER_FLAG\x10\x02\x12#\n\x1fMODERATION_TRIGGER_MACHINE_FLAG\x10\x03\x12\'\n#MODERATION_TRIGGER_MODERATOR_REVIEW\x10\x04*\xc8\x01\n\x10ModerationAction\x12!\n\x1dMODERATION_ACTION_UNSPECIFIED\x10\x00\x12\x1c\n\x18MODERATION_ACTION_CREATE\x10\x01\x12\x1d\n\x19MODERATION_ACTION_APPROVE\x10\x02\x12\x1a\n\x16MODERATION_ACTION_HIDE\x10\x03\x12\x1a\n\x16MODERATION_ACTION_FLAG\x10\x04\x12\x1c\n\x18MODERATION_ACTION_UNFLAG\x10\x05*\x8e\x01\n\x14ModerationObjectType\x12&\n\"MODERATION_OBJECT_TYPE_UNSPECIFIED\x10\x00\x12\'\n#MODERATION_OBJECT_TYPE_HOST_REQUEST\x10\x01\x12%\n!MODERATION_OBJECT_TYPE_GROUP_CHAT\x10\x02\x32\xca\x05\n\nModeration\x12v\n\x12GetModerationQueue\x12..org.couchers.moderation.GetModerationQueueReq\x1a..org.couchers.moderation.GetModerationQueueRes\"\x00\x12v\n\x12GetModerationState\x12..org.couchers.moderation.GetModerationStateReq\x1a..org.couchers.moderation.GetModerationStateRes\"\x00\x12p\n\x10GetModerationLog\x12,.org.couchers.moderation.GetModerationLogReq\x1a,.org.couchers.moderation.GetModerationLogRes\"\x00\x12m\n\x0fModerateContent\x12+.org.couchers.moderation.ModerateContentReq\x1a+.org.couchers.moderation.ModerateContentRes\"\x00\x12|\n\x14\x46lagContentForReview\x12\x30.org.couchers.moderation.FlagContentForReviewReq\x1a\x30.org.couchers.moderation.FlagContentForReviewRes\"\x00\x12g\n\rUnflagContent\x12).org.couchers.moderation.UnflagContentReq\x1a).org.couchers.moderation.UnflagContentRes\"\x00\x1a\x04\x88\xb5\x18\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'moderation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODERATION']._loaded_options = None
  _globals['_MODERATION']._serialized_options = b'\210\265\030\004'
  _globals['_MODERATIONVISIBILITY']._serialized_start=2643
  _globals['_MODERATIONVISIBILITY']._serialized_end=2845
  _globals['_MODERATIONTRIGGER']._serialized_start=2848
  _globals['_MODERATIONTRIGGER']._serialized_end=3054
  _globals['_MODERATIONACTION']._serialized_start=3057
  _globals['_MODERATIONACTION']._serialized_end=3257
  _globals['_MODERATIONOBJECTTYPE']._serialized_start=3260
  _globals['_MODERATIONOBJECTTYPE']._serialized_end=3402
  _globals['_MODERATIONSTATEINFO']._serialized_start=98
  _globals['_MODERATIONSTATEINFO']._serialized_end=392
  _globals['_MODERATIONQUEUEITEMINFO']._serialized_start=395
  _globals['_MODERATIONQUEUEITEMINFO']._serialized_end=749
  _globals['_MODERATIONLOGENTRYINFO']._serialized_start=752
  _globals['_MODERATIONLOGENTRYINFO']._serialized_end=1042
  _globals['_GETMODERATIONQUEUEREQ']._serialized_start=1045
  _globals['_GETMODERATIONQUEUEREQ']._serialized_end=1416
  _globals['_GETMODERATIONQUEUERES']._serialized_start=1418
  _globals['_GETMODERATIONQUEUERES']._serialized_end=1537
  _globals['_GETMODERATIONSTATEREQ']._serialized_start=1539
  _globals['_GETMODERATIONSTATEREQ']._serialized_end=1649
  _globals['_GETMODERATIONSTATERES']._serialized_start=1651
  _globals['_GETMODERATIONSTATERES']._serialized_end=1746
  _globals['_GETMODERATIONLOGREQ']._serialized_start=1748
  _globals['_GETMODERATIONLOGREQ']._serialized_end=1798
  _globals['_GETMODERATIONLOGRES']._serialized_start=1801
  _globals['_GETMODERATIONLOGRES']._serialized_end=1964
  _globals['_MODERATECONTENTREQ']._serialized_start=1967
  _globals['_MODERATECONTENTREQ']._serialized_end=2158
  _globals['_MODERATECONTENTRES']._serialized_start=2160
  _globals['_MODERATECONTENTRES']._serialized_end=2252
  _globals['_FLAGCONTENTFORREVIEWREQ']._serialized_start=2255
  _globals['_FLAGCONTENTFORREVIEWREQ']._serialized_end=2386
  _globals['_FLAGCONTENTFORREVIEWRES']._serialized_start=2388
  _globals['_FLAGCONTENTFORREVIEWRES']._serialized_end=2483
  _globals['_UNFLAGCONTENTREQ']._serialized_start=2485
  _globals['_UNFLAGCONTENTREQ']._serialized_end=2548
  _globals['_UNFLAGCONTENTRES']._serialized_start=2550
  _globals['_UNFLAGCONTENTRES']._serialized_end=2640
  _globals['_MODERATION']._serialized_start=3405
  _globals['_MODERATION']._serialized_end=4119
# @@protoc_insertion_point(module_scope)
