# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import threads_pb2 as threads__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x65vents.proto\x12\x17org.couchers.api.events\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\rthreads.proto\"&\n\x16OnlineEventInformation\x12\x0c\n\x04link\x18\x01 \x01(\t\"D\n\x17OfflineEventInformation\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lng\x18\x03 \x01(\x01\"\xd6\x07\n\x05\x45vent\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x0f\n\x07is_next\x18\x02 \x01(\x08\x12\x14\n\x0cis_cancelled\x18\x03 \x01(\x08\x12\x12\n\nis_deleted\x18\x04 \x01(\x08\x12\r\n\x05title\x18\x05 \x01(\t\x12\x0c\n\x04slug\x18\x06 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x07 \x01(\t\x12\x11\n\tphoto_url\x18\x08 \x01(\t\x12M\n\x12online_information\x18\t \x01(\x0b\x32/.org.couchers.api.events.OnlineEventInformationH\x00\x12O\n\x13offline_information\x18\n \x01(\x0b\x32\x30.org.couchers.api.events.OfflineEventInformationH\x00\x12+\n\x07\x63reated\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0blast_edited\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x63reator_user_id\x18\x0f \x01(\x03\x12.\n\nstart_time\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08timezone\x18\x12 \x01(\t\x12\x1a\n\x12start_time_display\x18\x13 \x01(\t\x12\x18\n\x10\x65nd_time_display\x18\x14 \x01(\t\x12\x42\n\x10\x61ttendance_state\x18\x15 \x01(\x0e\x32(.org.couchers.api.events.AttendanceState\x12\x11\n\torganizer\x18\x16 \x01(\x08\x12\x12\n\nsubscriber\x18\x17 \x01(\x08\x12\x13\n\x0bgoing_count\x18\x18 \x01(\r\x12\x13\n\x0bmaybe_count\x18\x19 \x01(\r\x12\x17\n\x0forganizer_count\x18\x1a \x01(\r\x12\x18\n\x10subscriber_count\x18\x1b \x01(\r\x12\x17\n\rowner_user_id\x18\x1c \x01(\x03H\x01\x12\x1c\n\x12owner_community_id\x18\x1d \x01(\x03H\x01\x12\x18\n\x0eowner_group_id\x18\x1e \x01(\x03H\x01\x12\x30\n\x06thread\x18\" \x01(\x0b\x32 .org.couchers.api.threads.Thread\x12\x10\n\x08\x63\x61n_edit\x18  \x01(\x08\x12\x14\n\x0c\x63\x61n_moderate\x18! \x01(\x08\x42\x06\n\x04modeB\x07\n\x05owner\"\xf8\x02\n\x0e\x43reateEventReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tphoto_key\x18\x03 \x01(\t\x12M\n\x12online_information\x18\x04 \x01(\x0b\x32/.org.couchers.api.events.OnlineEventInformationH\x00\x12O\n\x13offline_information\x18\x05 \x01(\x0b\x32\x30.org.couchers.api.events.OfflineEventInformationH\x00\x12\x1b\n\x13parent_community_id\x18\x08 \x01(\x03\x12.\n\nstart_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08timezone\x18\x0b \x01(\tB\x06\n\x04mode\"\xe0\x02\n\x10ScheduleEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tphoto_key\x18\x03 \x01(\t\x12M\n\x12online_information\x18\x04 \x01(\x0b\x32/.org.couchers.api.events.OnlineEventInformationH\x00\x12O\n\x13offline_information\x18\x05 \x01(\x0b\x32\x30.org.couchers.api.events.OfflineEventInformationH\x00\x12.\n\nstart_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08timezone\x18\n \x01(\tB\x06\n\x04mode\"\x97\x04\n\x0eUpdateEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x19\n\x11update_all_future\x18\x02 \x01(\x08\x12+\n\x05title\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07\x63ontent\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12/\n\tphoto_key\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12M\n\x12online_information\x18\x06 \x01(\x0b\x32/.org.couchers.api.events.OnlineEventInformationH\x00\x12O\n\x13offline_information\x18\x07 \x01(\x0b\x32\x30.org.couchers.api.events.OfflineEventInformationH\x00\x12.\n\nstart_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\x08timezone\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x15\n\rshould_notify\x18\x0c \x01(\x08\x42\x06\n\x04mode\"\x1f\n\x0bGetEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\"\"\n\x0e\x43\x61ncelEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\"-\n\x19RequestCommunityInviteReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\"P\n\x15ListEventAttendeesReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"K\n\x15ListEventAttendeesRes\x12\x19\n\x11\x61ttendee_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"R\n\x17ListEventSubscribersReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"O\n\x17ListEventSubscribersRes\x12\x1b\n\x13subscriber_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x16ListEventOrganizersReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"M\n\x16ListEventOrganizersRes\x12\x1a\n\x12organizer_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdb\x01\n\x0fListMyEventsReq\x12\x0c\n\x04past\x18\x01 \x01(\x08\x12\x12\n\nsubscribed\x18\x02 \x01(\x08\x12\x11\n\tattending\x18\x03 \x01(\x08\x12\x12\n\norganizing\x18\x04 \x01(\x08\x12\x16\n\x0emy_communities\x18\x07 \x01(\x08\x12\x19\n\x11include_cancelled\x18\x08 \x01(\x08\x12\x11\n\tpage_size\x18\x05 \x01(\r\x12\x14\n\npage_token\x18\x06 \x01(\tH\x00\x12\x15\n\x0bpage_number\x18\t \x01(\rH\x00\x42\x0c\n\npagination\"o\n\x0fListMyEventsRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x13\n\x0btotal_items\x18\x04 \x01(\r\"b\n\x10ListAllEventsReq\x12\x0c\n\x04past\x18\x01 \x01(\x08\x12\x19\n\x11include_cancelled\x18\x04 \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"[\n\x10ListAllEventsRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"{\n\x17ListEventOccurrencesReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x0c\n\x04past\x18\x02 \x01(\x08\x12\x19\n\x11include_cancelled\x18\x05 \x01(\x08\x12\x11\n\tpage_size\x18\x03 \x01(\r\x12\x12\n\npage_token\x18\x04 \x01(\t\"b\n\x17ListEventOccurrencesRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"q\n\x10TransferEventReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12 \n\x16new_owner_community_id\x18\x03 \x01(\x03H\x00\x12\x1c\n\x12new_owner_group_id\x18\x02 \x01(\x03H\x00\x42\x0b\n\tnew_owner\">\n\x17SetEventSubscriptionReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x11\n\tsubscribe\x18\x02 \x01(\x08\"m\n\x15SetEventAttendanceReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x42\n\x10\x61ttendance_state\x18\x02 \x01(\x0e\x32(.org.couchers.api.events.AttendanceState\"<\n\x17InviteEventOrganizerReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12\x0f\n\x07user_id\x18\x02 \x01(\x03\"Y\n\x17RemoveEventOrganizerReq\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\x03\x12,\n\x07user_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value*i\n\x0f\x41ttendanceState\x12\x1e\n\x1a\x41TTENDANCE_STATE_NOT_GOING\x10\x00\x12\x1a\n\x16\x41TTENDANCE_STATE_MAYBE\x10\x01\x12\x1a\n\x16\x41TTENDANCE_STATE_GOING\x10\x02\x32\xe6\r\n\x06\x45vents\x12X\n\x0b\x43reateEvent\x12\'.org.couchers.api.events.CreateEventReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12\\\n\rScheduleEvent\x12).org.couchers.api.events.ScheduleEventReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12X\n\x0bUpdateEvent\x12\'.org.couchers.api.events.UpdateEventReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12R\n\x08GetEvent\x12$.org.couchers.api.events.GetEventReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12P\n\x0b\x43\x61ncelEvent\x12\'.org.couchers.api.events.CancelEventReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x66\n\x16RequestCommunityInvite\x12\x32.org.couchers.api.events.RequestCommunityInviteReq\x1a\x16.google.protobuf.Empty\"\x00\x12|\n\x14ListEventOccurrences\x12\x30.org.couchers.api.events.ListEventOccurrencesReq\x1a\x30.org.couchers.api.events.ListEventOccurrencesRes\"\x00\x12v\n\x12ListEventAttendees\x12..org.couchers.api.events.ListEventAttendeesReq\x1a..org.couchers.api.events.ListEventAttendeesRes\"\x00\x12|\n\x14ListEventSubscribers\x12\x30.org.couchers.api.events.ListEventSubscribersReq\x1a\x30.org.couchers.api.events.ListEventSubscribersRes\"\x00\x12y\n\x13ListEventOrganizers\x12/.org.couchers.api.events.ListEventOrganizersReq\x1a/.org.couchers.api.events.ListEventOrganizersRes\"\x00\x12\\\n\rTransferEvent\x12).org.couchers.api.events.TransferEventReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12j\n\x14SetEventSubscription\x12\x30.org.couchers.api.events.SetEventSubscriptionReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12\x66\n\x12SetEventAttendance\x12..org.couchers.api.events.SetEventAttendanceReq\x1a\x1e.org.couchers.api.events.Event\"\x00\x12\x62\n\x14InviteEventOrganizer\x12\x30.org.couchers.api.events.InviteEventOrganizerReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x62\n\x14RemoveEventOrganizer\x12\x30.org.couchers.api.events.RemoveEventOrganizerReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x64\n\x0cListMyEvents\x12(.org.couchers.api.events.ListMyEventsReq\x1a(.org.couchers.api.events.ListMyEventsRes\"\x00\x12g\n\rListAllEvents\x12).org.couchers.api.events.ListAllEventsReq\x1a).org.couchers.api.events.ListAllEventsRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EVENTS']._loaded_options = None
  _globals['_EVENTS']._serialized_options = b'\210\265\030\003'
  _globals['_ATTENDANCESTATE']._serialized_start=4334
  _globals['_ATTENDANCESTATE']._serialized_end=4439
  _globals['_ONLINEEVENTINFORMATION']._serialized_start=169
  _globals['_ONLINEEVENTINFORMATION']._serialized_end=207
  _globals['_OFFLINEEVENTINFORMATION']._serialized_start=209
  _globals['_OFFLINEEVENTINFORMATION']._serialized_end=277
  _globals['_EVENT']._serialized_start=280
  _globals['_EVENT']._serialized_end=1262
  _globals['_CREATEEVENTREQ']._serialized_start=1265
  _globals['_CREATEEVENTREQ']._serialized_end=1641
  _globals['_SCHEDULEEVENTREQ']._serialized_start=1644
  _globals['_SCHEDULEEVENTREQ']._serialized_end=1996
  _globals['_UPDATEEVENTREQ']._serialized_start=1999
  _globals['_UPDATEEVENTREQ']._serialized_end=2534
  _globals['_GETEVENTREQ']._serialized_start=2536
  _globals['_GETEVENTREQ']._serialized_end=2567
  _globals['_CANCELEVENTREQ']._serialized_start=2569
  _globals['_CANCELEVENTREQ']._serialized_end=2603
  _globals['_REQUESTCOMMUNITYINVITEREQ']._serialized_start=2605
  _globals['_REQUESTCOMMUNITYINVITEREQ']._serialized_end=2650
  _globals['_LISTEVENTATTENDEESREQ']._serialized_start=2652
  _globals['_LISTEVENTATTENDEESREQ']._serialized_end=2732
  _globals['_LISTEVENTATTENDEESRES']._serialized_start=2734
  _globals['_LISTEVENTATTENDEESRES']._serialized_end=2809
  _globals['_LISTEVENTSUBSCRIBERSREQ']._serialized_start=2811
  _globals['_LISTEVENTSUBSCRIBERSREQ']._serialized_end=2893
  _globals['_LISTEVENTSUBSCRIBERSRES']._serialized_start=2895
  _globals['_LISTEVENTSUBSCRIBERSRES']._serialized_end=2974
  _globals['_LISTEVENTORGANIZERSREQ']._serialized_start=2976
  _globals['_LISTEVENTORGANIZERSREQ']._serialized_end=3057
  _globals['_LISTEVENTORGANIZERSRES']._serialized_start=3059
  _globals['_LISTEVENTORGANIZERSRES']._serialized_end=3136
  _globals['_LISTMYEVENTSREQ']._serialized_start=3139
  _globals['_LISTMYEVENTSREQ']._serialized_end=3358
  _globals['_LISTMYEVENTSRES']._serialized_start=3360
  _globals['_LISTMYEVENTSRES']._serialized_end=3471
  _globals['_LISTALLEVENTSREQ']._serialized_start=3473
  _globals['_LISTALLEVENTSREQ']._serialized_end=3571
  _globals['_LISTALLEVENTSRES']._serialized_start=3573
  _globals['_LISTALLEVENTSRES']._serialized_end=3664
  _globals['_LISTEVENTOCCURRENCESREQ']._serialized_start=3666
  _globals['_LISTEVENTOCCURRENCESREQ']._serialized_end=3789
  _globals['_LISTEVENTOCCURRENCESRES']._serialized_start=3791
  _globals['_LISTEVENTOCCURRENCESRES']._serialized_end=3889
  _globals['_TRANSFEREVENTREQ']._serialized_start=3891
  _globals['_TRANSFEREVENTREQ']._serialized_end=4004
  _globals['_SETEVENTSUBSCRIPTIONREQ']._serialized_start=4006
  _globals['_SETEVENTSUBSCRIPTIONREQ']._serialized_end=4068
  _globals['_SETEVENTATTENDANCEREQ']._serialized_start=4070
  _globals['_SETEVENTATTENDANCEREQ']._serialized_end=4179
  _globals['_INVITEEVENTORGANIZERREQ']._serialized_start=4181
  _globals['_INVITEEVENTORGANIZERREQ']._serialized_end=4241
  _globals['_REMOVEEVENTORGANIZERREQ']._serialized_start=4243
  _globals['_REMOVEEVENTORGANIZERREQ']._serialized_end=4332
  _globals['_EVENTS']._serialized_start=4442
  _globals['_EVENTS']._serialized_end=6208
# @@protoc_insertion_point(module_scope)
