"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.internal.extension_dict
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AuthLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AuthLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AuthLevel.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    AUTH_LEVEL_UNKNOWN: _AuthLevel.ValueType  # 0
    """error"""
    AUTH_LEVEL_OPEN: _AuthLevel.ValueType  # 1
    """accessible to all"""
    AUTH_LEVEL_JAILED: _AuthLevel.ValueType  # 2
    """accessible to users who need to finish some things to get into the app"""
    AUTH_LEVEL_SECURE: _AuthLevel.ValueType  # 3
    """accessible to all signed in users"""
    AUTH_LEVEL_EDITOR: _AuthLevel.ValueType  # 5
    """accessible to editors (admin-lite: can create communities, modify volunteer data)"""
    AUTH_LEVEL_ADMIN: _AuthLevel.ValueType  # 4
    """accessible only by the Couchers organization"""

class AuthLevel(_AuthLevel, metaclass=_AuthLevelEnumTypeWrapper): ...

AUTH_LEVEL_UNKNOWN: AuthLevel.ValueType  # 0
"""error"""
AUTH_LEVEL_OPEN: AuthLevel.ValueType  # 1
"""accessible to all"""
AUTH_LEVEL_JAILED: AuthLevel.ValueType  # 2
"""accessible to users who need to finish some things to get into the app"""
AUTH_LEVEL_SECURE: AuthLevel.ValueType  # 3
"""accessible to all signed in users"""
AUTH_LEVEL_EDITOR: AuthLevel.ValueType  # 5
"""accessible to editors (admin-lite: can create communities, modify volunteer data)"""
AUTH_LEVEL_ADMIN: AuthLevel.ValueType  # 4
"""accessible only by the Couchers organization"""
Global___AuthLevel: typing_extensions.TypeAlias = AuthLevel

SENSITIVE_FIELD_NUMBER: builtins.int
IS_TOKEN_FIELD_NUMBER: builtins.int
AUTH_LEVEL_FIELD_NUMBER: builtins.int
sensitive: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
"""whether the field is sensitive and should not be logged"""
is_token: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
"""this is a token"""
auth_level: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.ServiceOptions, Global___AuthLevel.ValueType]
"""the auth level required to access this service, one of"""
