# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: search.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2
from . import communities_pb2 as communities__pb2
from . import events_pb2 as events__pb2
from . import groups_pb2 as groups__pb2
from . import pages_pb2 as pages__pb2
from . import requests_pb2 as requests__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csearch.proto\x12\x17org.couchers.api.search\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\x1a\x11\x63ommunities.proto\x1a\x0c\x65vents.proto\x1a\x0cgroups.proto\x1a\x0bpages.proto\x1a\x0erequests.proto\"0\n\x04\x41rea\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\x12\x0e\n\x06radius\x18\x03 \x01(\x01\"N\n\x08RectArea\x12\x0f\n\x07lat_min\x18\x01 \x01(\x01\x12\x0f\n\x07lat_max\x18\x02 \x01(\x01\x12\x0f\n\x07lng_min\x18\x03 \x01(\x01\x12\x0f\n\x07lng_max\x18\x04 \x01(\x01\"\xe9\x01\n\tSearchReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x15\n\rinclude_users\x18\x04 \x01(\x08\x12\x1b\n\x13include_communities\x18\x05 \x01(\x08\x12\x16\n\x0einclude_groups\x18\x06 \x01(\x08\x12\x16\n\x0einclude_places\x18\x07 \x01(\x08\x12\x16\n\x0einclude_guides\x18\x08 \x01(\x08\x12\x16\n\x0einclude_events\x18\n \x01(\x08\x12\x12\n\ntitle_only\x18\r \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"\xdc\x02\n\x06Result\x12\x0c\n\x04rank\x18\x01 \x01(\x01\x12\x0f\n\x07snippet\x18\x02 \x01(\t\x12+\n\x04user\x18\x03 \x01(\x0b\x32\x1b.org.couchers.api.core.UserH\x00\x12<\n\tcommunity\x18\x04 \x01(\x0b\x32\'.org.couchers.api.communities.CommunityH\x00\x12/\n\x05group\x18\x05 \x01(\x0b\x32\x1e.org.couchers.api.groups.GroupH\x00\x12-\n\x05place\x18\x06 \x01(\x0b\x32\x1c.org.couchers.api.pages.PageH\x00\x12-\n\x05guide\x18\x07 \x01(\x0b\x32\x1c.org.couchers.api.pages.PageH\x00\x12/\n\x05\x65vent\x18\x08 \x01(\x0b\x32\x1e.org.couchers.api.events.EventH\x00\x42\x08\n\x06result\"V\n\tSearchRes\x12\x30\n\x07results\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.search.Result\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa0\r\n\rUserSearchReq\x12\x18\n\x10\x65xactly_user_ids\x18# \x03(\x03\x12+\n\x05query\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x17\n\x0fquery_name_only\x18\x1e \x01(\x08\x12/\n\x0blast_active\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x0esearch_in_area\x18\x1c \x01(\x0b\x32\x1d.org.couchers.api.search.AreaH\x00\x12 \n\x16search_in_community_id\x18\x1d \x01(\x03H\x00\x12@\n\x13search_in_rectangle\x18! \x01(\x0b\x32!.org.couchers.api.search.RectAreaH\x00\x12\x43\n\x15hosting_status_filter\x18\x05 \x03(\x0e\x32$.org.couchers.api.core.HostingStatus\x12G\n\x17smoking_location_filter\x18\x06 \x03(\x0e\x32&.org.couchers.api.core.SmokingLocation\x12O\n\x1bsleeping_arrangement_filter\x18\x07 \x03(\x0e\x32*.org.couchers.api.core.SleepingArrangement\x12\x45\n\x16parking_details_filter\x18\x08 \x03(\x0e\x32%.org.couchers.api.core.ParkingDetails\x12\x41\n\x14meetup_status_filter\x18  \x03(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12G\n\x17language_ability_filter\x18\x0b \x03(\x0b\x32&.org.couchers.api.core.LanguageAbility\x12,\n\x06guests\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1c\n\x14only_with_references\x18\x0c \x01(\x08\x12%\n\x1donly_with_strong_verification\x18\" \x01(\x08\x12-\n\x07\x61ge_min\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12-\n\x07\x61ge_max\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\x0blast_minute\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08has_pets\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_pets\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08has_kids\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_kids\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0ehas_housemates\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15wheelchair_accessible\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0esmokes_at_home\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x64rinking_allowed\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x64rinks_at_home\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07parking\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\ncamping_ok\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11profile_completed\x18\x1f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x18\n\x10same_gender_only\x18$ \x01(\x08\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\tB\x0b\n\tsearch_in\"o\n\rUserSearchRes\x12\x30\n\x07results\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.search.Result\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x13\n\x0btotal_items\x18\x03 \x01(\r\"\xff\x06\n\nSearchUser\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x63ity\x18\x04 \x01(\t\x12*\n\x06joined\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15has_completed_profile\x18\x05 \x01(\x08\x12\x1d\n\x15has_completed_my_home\x18\x17 \x01(\x08\x12\x0b\n\x03lat\x18\x06 \x01(\x01\x12\x0b\n\x03lng\x18\x07 \x01(\x01\x12\x17\n\x0fprofile_snippet\x18\x08 \x01(\t\x12\x16\n\x0enum_references\x18\t \x01(\r\x12\x0e\n\x06gender\x18\n \x01(\t\x12\x0b\n\x03\x61ge\x18\x0b \x01(\r\x12/\n\x0blast_active\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x0ehosting_status\x18\r \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12:\n\rmeetup_status\x18\x0e \x01(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12\x12\n\navatar_url\x18\x0f \x01(\t\x12\x1c\n\x14\x61vatar_thumbnail_url\x18\x10 \x01(\t\x12\x1f\n\x17has_strong_verification\x18\x11 \x01(\x08\x12T\n\x11insufficient_data\x18\x12 \x01(\x0b\x32\x37.org.couchers.api.requests.ResponseRateInsufficientDataH\x00\x12\x39\n\x03low\x18\x13 \x01(\x0b\x32*.org.couchers.api.requests.ResponseRateLowH\x00\x12;\n\x04some\x18\x14 \x01(\x0b\x32+.org.couchers.api.requests.ResponseRateSomeH\x00\x12;\n\x04most\x18\x15 \x01(\x0b\x32+.org.couchers.api.requests.ResponseRateMostH\x00\x12\x46\n\nalmost_all\x18\x16 \x01(\x0b\x32\x30.org.couchers.api.requests.ResponseRateAlmostAllH\x00\x42\x0f\n\rresponse_rate\"u\n\x0fUserSearchV2Res\x12\x34\n\x07results\x18\x01 \x03(\x0b\x32#.org.couchers.api.search.SearchUser\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x13\n\x0btotal_items\x18\x03 \x01(\r\"\xe2\x04\n\x0e\x45ventSearchReq\x12\x0c\n\x04past\x18\x01 \x01(\x08\x12+\n\x05query\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x18\n\x10query_title_only\x18\x03 \x01(\x08\x12\x15\n\x0bonly_online\x18\x0c \x01(\x08H\x00\x12\x16\n\x0conly_offline\x18\r \x01(\x08H\x00\x12\x12\n\nsubscribed\x18\x0e \x01(\x08\x12\x11\n\tattending\x18\x0f \x01(\x08\x12\x12\n\norganizing\x18\x10 \x01(\x08\x12\x16\n\x0emy_communities\x18\x11 \x01(\x08\x12\x19\n\x11include_cancelled\x18\x04 \x01(\x08\x12\x37\n\x0esearch_in_area\x18\x05 \x01(\x0b\x32\x1d.org.couchers.api.search.AreaH\x01\x12 \n\x16search_in_community_id\x18\x06 \x01(\x03H\x01\x12@\n\x13search_in_rectangle\x18\x07 \x01(\x0b\x32!.org.couchers.api.search.RectAreaH\x01\x12)\n\x05\x61\x66ter\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x62\x65\x66ore\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tpage_size\x18\n \x01(\r\x12\x14\n\npage_token\x18\x0b \x01(\tH\x02\x12\x15\n\x0bpage_number\x18\x12 \x01(\rH\x02\x42\x0f\n\ronline_statusB\x0b\n\tsearch_inB\x0c\n\npagination\"n\n\x0e\x45ventSearchRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x13\n\x0btotal_items\x18\x04 \x01(\r2\x89\x03\n\x06Search\x12R\n\x06Search\x12\".org.couchers.api.search.SearchReq\x1a\".org.couchers.api.search.SearchRes\"\x00\x12^\n\nUserSearch\x12&.org.couchers.api.search.UserSearchReq\x1a&.org.couchers.api.search.UserSearchRes\"\x00\x12\x62\n\x0cUserSearchV2\x12&.org.couchers.api.search.UserSearchReq\x1a(.org.couchers.api.search.UserSearchV2Res\"\x00\x12\x61\n\x0b\x45ventSearch\x12\'.org.couchers.api.search.EventSearchReq\x1a\'.org.couchers.api.search.EventSearchRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'search_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SEARCH']._loaded_options = None
  _globals['_SEARCH']._serialized_options = b'\210\265\030\003'
  _globals['_AREA']._serialized_start=212
  _globals['_AREA']._serialized_end=260
  _globals['_RECTAREA']._serialized_start=262
  _globals['_RECTAREA']._serialized_end=340
  _globals['_SEARCHREQ']._serialized_start=343
  _globals['_SEARCHREQ']._serialized_end=576
  _globals['_RESULT']._serialized_start=579
  _globals['_RESULT']._serialized_end=927
  _globals['_SEARCHRES']._serialized_start=929
  _globals['_SEARCHRES']._serialized_end=1015
  _globals['_USERSEARCHREQ']._serialized_start=1018
  _globals['_USERSEARCHREQ']._serialized_end=2714
  _globals['_USERSEARCHRES']._serialized_start=2716
  _globals['_USERSEARCHRES']._serialized_end=2827
  _globals['_SEARCHUSER']._serialized_start=2830
  _globals['_SEARCHUSER']._serialized_end=3725
  _globals['_USERSEARCHV2RES']._serialized_start=3727
  _globals['_USERSEARCHV2RES']._serialized_end=3844
  _globals['_EVENTSEARCHREQ']._serialized_start=3847
  _globals['_EVENTSEARCHREQ']._serialized_end=4457
  _globals['_EVENTSEARCHRES']._serialized_start=4459
  _globals['_EVENTSEARCHRES']._serialized_end=4569
  _globals['_SEARCH']._serialized_start=4572
  _globals['_SEARCH']._serialized_end=4965
# @@protoc_insertion_point(module_scope)
