# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: reporting.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0freporting.proto\x12\x1aorg.couchers.api.reporting\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"|\n\tReportReq\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x63ontent_ref\x18\x03 \x01(\t\x12\x13\n\x0b\x61uthor_user\x18\x04 \x01(\t\x12\x12\n\nuser_agent\x18\x05 \x01(\t\x12\x0c\n\x04page\x18\x06 \x01(\t2\\\n\tReporting\x12I\n\x06Report\x12%.org.couchers.api.reporting.ReportReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'reporting_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REPORTING']._loaded_options = None
  _globals['_REPORTING']._serialized_options = b'\210\265\030\003'
  _globals['_REPORTREQ']._serialized_start=95
  _globals['_REPORTREQ']._serialized_end=219
  _globals['_REPORTING']._serialized_start=221
  _globals['_REPORTING']._serialized_end=313
# @@protoc_insertion_point(module_scope)
