# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: editor.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import communities_pb2 as communities__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x65\x64itor.proto\x12\x13org.couchers.editor\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\x11\x63ommunities.proto\"s\n\x12\x43reateCommunityReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0eparent_node_id\x18\x04 \x01(\x03\x12\x11\n\tadmin_ids\x18\x05 \x03(\x03\x12\x0f\n\x07geojson\x18\x06 \x01(\t\"v\n\x12UpdateCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0eparent_node_id\x18\x04 \x01(\x03\x12\x0f\n\x07geojson\x18\x05 \x01(\t\"L\n#ListEventCommunityInviteRequestsReq\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"\xa2\x01\n\x1b\x45ventCommunityInviteRequest\x12)\n!event_community_invite_request_id\x18\x01 \x01(\x03\x12\x0f\n\x07user_id\x18\x02 \x01(\x03\x12\x11\n\tevent_url\x18\x03 \x01(\t\x12\x1e\n\x16\x61pprox_users_to_notify\x18\x04 \x01(\r\x12\x14\n\x0c\x63ommunity_id\x18\x05 \x01(\x03\"\x82\x01\n#ListEventCommunityInviteRequestsRes\x12\x42\n\x08requests\x18\x01 \x03(\x0b\x32\x30.org.couchers.editor.EventCommunityInviteRequest\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"b\n$DecideEventCommunityInviteRequestReq\x12)\n!event_community_invite_request_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x61pprove\x18\x02 \x01(\x08\"&\n$DecideEventCommunityInviteRequestRes\"H\n\x1bSendBlogPostNotificationReq\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x62lurb\x18\x03 \x01(\t\"n\n\x14MakeUserVolunteerReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x1c\n\x14started_volunteering\x18\x03 \x01(\t\x12\x19\n\x11hide_on_team_page\x18\x04 \x01(\x08\"\xb0\x02\n\x12UpdateVolunteerReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12*\n\x04role\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08sort_key\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12:\n\x14started_volunteering\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14stopped_volunteering\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x11show_on_team_page\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\")\n\x11ListVolunteersReq\x12\x14\n\x0cinclude_past\x18\x01 \x01(\x08\"\x8b\x03\n\tVolunteer\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x17\n\x0fis_board_member\x18\x04 \x01(\x08\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0b\n\x03img\x18\x07 \x01(\t\x12\x15\n\x08sort_key\x18\x08 \x01(\x01H\x00\x88\x01\x01\x12\x1c\n\x14started_volunteering\x18\t \x01(\t\x12!\n\x14stopped_volunteering\x18\n \x01(\tH\x01\x88\x01\x01\x12\x19\n\x11show_on_team_page\x18\x0b \x01(\x08\x12\x16\n\tlink_type\x18\x0c \x01(\tH\x02\x88\x01\x01\x12\x16\n\tlink_text\x18\r \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08link_url\x18\x0e \x01(\tH\x04\x88\x01\x01\x42\x0b\n\t_sort_keyB\x17\n\x15_stopped_volunteeringB\x0c\n\n_link_typeB\x0c\n\n_link_textB\x0b\n\t_link_url\"G\n\x11ListVolunteersRes\x12\x32\n\nvolunteers\x18\x01 \x03(\x0b\x32\x1e.org.couchers.editor.Volunteer2\xa1\x07\n\x06\x45\x64itor\x12\x65\n\x0f\x43reateCommunity\x12\'.org.couchers.editor.CreateCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12\x65\n\x0fUpdateCommunity\x12\'.org.couchers.editor.UpdateCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12\x98\x01\n ListEventCommunityInviteRequests\x12\x38.org.couchers.editor.ListEventCommunityInviteRequestsReq\x1a\x38.org.couchers.editor.ListEventCommunityInviteRequestsRes\"\x00\x12\x9b\x01\n!DecideEventCommunityInviteRequest\x12\x39.org.couchers.editor.DecideEventCommunityInviteRequestReq\x1a\x39.org.couchers.editor.DecideEventCommunityInviteRequestRes\"\x00\x12\x66\n\x18SendBlogPostNotification\x12\x30.org.couchers.editor.SendBlogPostNotificationReq\x1a\x16.google.protobuf.Empty\"\x00\x12`\n\x11MakeUserVolunteer\x12).org.couchers.editor.MakeUserVolunteerReq\x1a\x1e.org.couchers.editor.Volunteer\"\x00\x12\\\n\x0fUpdateVolunteer\x12\'.org.couchers.editor.UpdateVolunteerReq\x1a\x1e.org.couchers.editor.Volunteer\"\x00\x12\x62\n\x0eListVolunteers\x12&.org.couchers.editor.ListVolunteersReq\x1a&.org.couchers.editor.ListVolunteersRes\"\x00\x1a\x04\x88\xb5\x18\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'editor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EDITOR']._loaded_options = None
  _globals['_EDITOR']._serialized_options = b'\210\265\030\005'
  _globals['_CREATECOMMUNITYREQ']._serialized_start=136
  _globals['_CREATECOMMUNITYREQ']._serialized_end=251
  _globals['_UPDATECOMMUNITYREQ']._serialized_start=253
  _globals['_UPDATECOMMUNITYREQ']._serialized_end=371
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSREQ']._serialized_start=373
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSREQ']._serialized_end=449
  _globals['_EVENTCOMMUNITYINVITEREQUEST']._serialized_start=452
  _globals['_EVENTCOMMUNITYINVITEREQUEST']._serialized_end=614
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSRES']._serialized_start=617
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSRES']._serialized_end=747
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTREQ']._serialized_start=749
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTREQ']._serialized_end=847
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTRES']._serialized_start=849
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTRES']._serialized_end=887
  _globals['_SENDBLOGPOSTNOTIFICATIONREQ']._serialized_start=889
  _globals['_SENDBLOGPOSTNOTIFICATIONREQ']._serialized_end=961
  _globals['_MAKEUSERVOLUNTEERREQ']._serialized_start=963
  _globals['_MAKEUSERVOLUNTEERREQ']._serialized_end=1073
  _globals['_UPDATEVOLUNTEERREQ']._serialized_start=1076
  _globals['_UPDATEVOLUNTEERREQ']._serialized_end=1380
  _globals['_LISTVOLUNTEERSREQ']._serialized_start=1382
  _globals['_LISTVOLUNTEERSREQ']._serialized_end=1423
  _globals['_VOLUNTEER']._serialized_start=1426
  _globals['_VOLUNTEER']._serialized_end=1821
  _globals['_LISTVOLUNTEERSRES']._serialized_start=1823
  _globals['_LISTVOLUNTEERSRES']._serialized_end=1894
  _globals['_EDITOR']._serialized_start=1897
  _globals['_EDITOR']._serialized_end=2826
# @@protoc_insertion_point(module_scope)
