"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BlockUserReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    username: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["username", b"username"]) -> None: ...

Global___BlockUserReq: typing_extensions.TypeAlias = BlockUserReq

@typing.final
class UnblockUserReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    username: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["username", b"username"]) -> None: ...

Global___UnblockUserReq: typing_extensions.TypeAlias = UnblockUserReq

@typing.final
class BlockedUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AVATAR_THUMBNAIL_URL_FIELD_NUMBER: builtins.int
    username: builtins.str
    name: builtins.str
    avatar_thumbnail_url: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
        name: builtins.str | None = ...,
        avatar_thumbnail_url: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["avatar_thumbnail_url", b"avatar_thumbnail_url", "name", b"name", "username", b"username"]) -> None: ...

Global___BlockedUser: typing_extensions.TypeAlias = BlockedUser

@typing.final
class GetBlockedUsersRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCKED_USERS_FIELD_NUMBER: builtins.int
    @property
    def blocked_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___BlockedUser]: ...
    def __init__(
        self,
        *,
        blocked_users: collections.abc.Iterable[Global___BlockedUser] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["blocked_users", b"blocked_users"]) -> None: ...

Global___GetBlockedUsersRes: typing_extensions.TypeAlias = GetBlockedUsersRes
