# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: galleries.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fgalleries.proto\x12\x1aorg.couchers.api.galleries\x1a\x11\x61nnotations.proto\"]\n\x10PhotoGalleryItem\x12\x0f\n\x07item_id\x18\x01 \x01(\x03\x12\x10\n\x08\x66ull_url\x18\x02 \x01(\t\x12\x15\n\rthumbnail_url\x18\x03 \x01(\t\x12\x0f\n\x07\x63\x61ption\x18\x04 \x01(\t\"r\n\x0cPhotoGallery\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12<\n\x06photos\x18\x02 \x03(\x0b\x32,.org.couchers.api.galleries.PhotoGalleryItem\x12\x10\n\x08\x63\x61n_edit\x18\x03 \x01(\x08\"#\n\rGetGalleryReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\"O\n\x14\x41\x64\x64PhotoToGalleryReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12\x12\n\nupload_key\x18\x02 \x01(\t\x12\x0f\n\x07\x63\x61ption\x18\x03 \x01(\t\"@\n\x19RemovePhotoFromGalleryReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12\x0f\n\x07item_id\x18\x02 \x01(\x03\"J\n\x0cMovePhotoReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12\x0f\n\x07item_id\x18\x02 \x01(\x03\x12\x15\n\rafter_item_id\x18\x03 \x01(\x03\"M\n\x15UpdatePhotoCaptionReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12\x0f\n\x07item_id\x18\x02 \x01(\x03\x12\x0f\n\x07\x63\x61ption\x18\x03 \x01(\t\"+\n\x15GetGalleryEditInfoReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\"\\\n\x15GetGalleryEditInfoRes\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12\x12\n\nmax_photos\x18\x02 \x01(\r\x12\x1b\n\x13\x63urrent_photo_count\x18\x03 \x01(\r2\xbc\x05\n\tGalleries\x12\x63\n\nGetGallery\x12).org.couchers.api.galleries.GetGalleryReq\x1a(.org.couchers.api.galleries.PhotoGallery\"\x00\x12q\n\x11\x41\x64\x64PhotoToGallery\x12\x30.org.couchers.api.galleries.AddPhotoToGalleryReq\x1a(.org.couchers.api.galleries.PhotoGallery\"\x00\x12{\n\x16RemovePhotoFromGallery\x12\x35.org.couchers.api.galleries.RemovePhotoFromGalleryReq\x1a(.org.couchers.api.galleries.PhotoGallery\"\x00\x12\x61\n\tMovePhoto\x12(.org.couchers.api.galleries.MovePhotoReq\x1a(.org.couchers.api.galleries.PhotoGallery\"\x00\x12s\n\x12UpdatePhotoCaption\x12\x31.org.couchers.api.galleries.UpdatePhotoCaptionReq\x1a(.org.couchers.api.galleries.PhotoGallery\"\x00\x12|\n\x12GetGalleryEditInfo\x12\x31.org.couchers.api.galleries.GetGalleryEditInfoReq\x1a\x31.org.couchers.api.galleries.GetGalleryEditInfoRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'galleries_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GALLERIES']._loaded_options = None
  _globals['_GALLERIES']._serialized_options = b'\210\265\030\003'
  _globals['_PHOTOGALLERYITEM']._serialized_start=66
  _globals['_PHOTOGALLERYITEM']._serialized_end=159
  _globals['_PHOTOGALLERY']._serialized_start=161
  _globals['_PHOTOGALLERY']._serialized_end=275
  _globals['_GETGALLERYREQ']._serialized_start=277
  _globals['_GETGALLERYREQ']._serialized_end=312
  _globals['_ADDPHOTOTOGALLERYREQ']._serialized_start=314
  _globals['_ADDPHOTOTOGALLERYREQ']._serialized_end=393
  _globals['_REMOVEPHOTOFROMGALLERYREQ']._serialized_start=395
  _globals['_REMOVEPHOTOFROMGALLERYREQ']._serialized_end=459
  _globals['_MOVEPHOTOREQ']._serialized_start=461
  _globals['_MOVEPHOTOREQ']._serialized_end=535
  _globals['_UPDATEPHOTOCAPTIONREQ']._serialized_start=537
  _globals['_UPDATEPHOTOCAPTIONREQ']._serialized_end=614
  _globals['_GETGALLERYEDITINFOREQ']._serialized_start=616
  _globals['_GETGALLERYEDITINFOREQ']._serialized_end=659
  _globals['_GETGALLERYEDITINFORES']._serialized_start=661
  _globals['_GETGALLERYEDITINFORES']._serialized_end=753
  _globals['_GALLERIES']._serialized_start=756
  _globals['_GALLERIES']._serialized_end=1456
# @@protoc_insertion_point(module_scope)
