# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blocking.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x62locking.proto\x12\x15org.couchers.blocking\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\" \n\x0c\x42lockUserReq\x12\x10\n\x08username\x18\x01 \x01(\t\"\"\n\x0eUnblockUserReq\x12\x10\n\x08username\x18\x01 \x01(\t\"K\n\x0b\x42lockedUser\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x14\x61vatar_thumbnail_url\x18\x03 \x01(\t\"O\n\x12GetBlockedUsersRes\x12\x39\n\rblocked_users\x18\x01 \x03(\x0b\x32\".org.couchers.blocking.BlockedUser2\x80\x02\n\x08\x42locking\x12H\n\tBlockUser\x12#.org.couchers.blocking.BlockUserReq\x1a\x16.google.protobuf.Empty\x12L\n\x0bUnblockUser\x12%.org.couchers.blocking.UnblockUserReq\x1a\x16.google.protobuf.Empty\x12V\n\x0fGetBlockedUsers\x12\x16.google.protobuf.Empty\x1a).org.couchers.blocking.GetBlockedUsersRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'blocking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BLOCKING']._loaded_options = None
  _globals['_BLOCKING']._serialized_options = b'\210\265\030\003'
  _globals['_BLOCKUSERREQ']._serialized_start=89
  _globals['_BLOCKUSERREQ']._serialized_end=121
  _globals['_UNBLOCKUSERREQ']._serialized_start=123
  _globals['_UNBLOCKUSERREQ']._serialized_end=157
  _globals['_BLOCKEDUSER']._serialized_start=159
  _globals['_BLOCKEDUSER']._serialized_end=234
  _globals['_GETBLOCKEDUSERSRES']._serialized_start=236
  _globals['_GETBLOCKEDUSERSRES']._serialized_end=315
  _globals['_BLOCKING']._serialized_start=318
  _globals['_BLOCKING']._serialized_end=574
# @@protoc_insertion_point(module_scope)
