from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import gallery_pb2
import grpc
import grpc.aio
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class GalleryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetGallery(
        self,
        request: gallery_pb2.GetGalleryReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.PhotoGallery, collections.abc.Awaitable[gallery_pb2.PhotoGallery]]:
        """Get a specific gallery by ID"""

    @abc.abstractmethod
    def AddPhotoToGallery(
        self,
        request: gallery_pb2.AddPhotoToGalleryReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.PhotoGallery, collections.abc.Awaitable[gallery_pb2.PhotoGallery]]:
        """Add a photo to your gallery (appended to end)"""

    @abc.abstractmethod
    def RemovePhotoFromGallery(
        self,
        request: gallery_pb2.RemovePhotoFromGalleryReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.PhotoGallery, collections.abc.Awaitable[gallery_pb2.PhotoGallery]]:
        """Remove a photo from your gallery"""

    @abc.abstractmethod
    def MovePhoto(
        self,
        request: gallery_pb2.MovePhotoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.PhotoGallery, collections.abc.Awaitable[gallery_pb2.PhotoGallery]]:
        """Move a photo to a new position in the gallery"""

    @abc.abstractmethod
    def UpdatePhotoCaption(
        self,
        request: gallery_pb2.UpdatePhotoCaptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.PhotoGallery, collections.abc.Awaitable[gallery_pb2.PhotoGallery]]:
        """Update the caption of a specific photo"""

    @abc.abstractmethod
    def GetGalleryEditInfo(
        self,
        request: gallery_pb2.GetGalleryEditInfoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.GetGalleryEditInfoRes, collections.abc.Awaitable[gallery_pb2.GetGalleryEditInfoRes]]:
        """Get edit info for a gallery you own (e.g., max_photos)"""

def add_GalleryServicer_to_server(servicer: GalleryServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
