# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: discussions.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import threads_pb2 as threads__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64iscussions.proto\x12\x1corg.couchers.api.discussions\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\rthreads.proto\"\xb5\x02\n\nDiscussion\x12\x15\n\rdiscussion_id\x18\x01 \x01(\x03\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12+\n\x07\x63reated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x63reator_user_id\x18\x04 \x01(\x03\x12\x1c\n\x12owner_community_id\x18\x05 \x01(\x03H\x00\x12\x18\n\x0eowner_group_id\x18\x06 \x01(\x03H\x00\x12\x13\n\x0bowner_title\x18\x0c \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x08 \x01(\t\x12\x30\n\x06thread\x18\x0b \x01(\x0b\x32 .org.couchers.api.threads.Thread\x12\x14\n\x0c\x63\x61n_moderate\x18\n \x01(\x08\x42\x07\n\x05owner\"v\n\x13\x43reateDiscussionReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x1c\n\x12owner_community_id\x18\x03 \x01(\x03H\x00\x12\x18\n\x0eowner_group_id\x18\x04 \x01(\x03H\x00\x42\x07\n\x05owner\")\n\x10GetDiscussionReq\x12\x15\n\rdiscussion_id\x18\x01 \x01(\x03\x32\xf3\x01\n\x0b\x44iscussions\x12q\n\x10\x43reateDiscussion\x12\x31.org.couchers.api.discussions.CreateDiscussionReq\x1a(.org.couchers.api.discussions.Discussion\"\x00\x12k\n\rGetDiscussion\x12..org.couchers.api.discussions.GetDiscussionReq\x1a(.org.couchers.api.discussions.Discussion\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'discussions_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DISCUSSIONS']._loaded_options = None
  _globals['_DISCUSSIONS']._serialized_options = b'\210\265\030\003'
  _globals['_DISCUSSION']._serialized_start=119
  _globals['_DISCUSSION']._serialized_end=428
  _globals['_CREATEDISCUSSIONREQ']._serialized_start=430
  _globals['_CREATEDISCUSSIONREQ']._serialized_end=548
  _globals['_GETDISCUSSIONREQ']._serialized_start=550
  _globals['_GETDISCUSSIONREQ']._serialized_end=591
  _globals['_DISCUSSIONS']._serialized_start=594
  _globals['_DISCUSSIONS']._serialized_end=837
# @@protoc_insertion_point(module_scope)
