# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: threads.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rthreads.proto\x12\x18org.couchers.api.threads\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\"2\n\x06Thread\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x15\n\rnum_responses\x18\x02 \x01(\x03\"H\n\x0cGetThreadReq\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"Y\n\x0cGetThreadRes\x12\x30\n\x07replies\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.threads.Reply\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\"\x8a\x01\n\x05Reply\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x16\n\x0e\x61uthor_user_id\x18\x03 \x01(\x03\x12\x30\n\x0c\x63reated_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bnum_replies\x18\x05 \x01(\r\"2\n\x0cPostReplyReq\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"!\n\x0cPostReplyRes\x12\x11\n\tthread_id\x18\x01 \x01(\x03\x32\xc9\x01\n\x07Threads\x12[\n\tGetThread\x12&.org.couchers.api.threads.GetThreadReq\x1a&.org.couchers.api.threads.GetThreadRes\x12[\n\tPostReply\x12&.org.couchers.api.threads.PostReplyReq\x1a&.org.couchers.api.threads.PostReplyRes\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'threads_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_THREADS']._loaded_options = None
  _globals['_THREADS']._serialized_options = b'\210\265\030\003'
  _globals['_THREAD']._serialized_start=95
  _globals['_THREAD']._serialized_end=145
  _globals['_GETTHREADREQ']._serialized_start=147
  _globals['_GETTHREADREQ']._serialized_end=219
  _globals['_GETTHREADRES']._serialized_start=221
  _globals['_GETTHREADRES']._serialized_end=310
  _globals['_REPLY']._serialized_start=313
  _globals['_REPLY']._serialized_end=451
  _globals['_POSTREPLYREQ']._serialized_start=453
  _globals['_POSTREPLYREQ']._serialized_end=503
  _globals['_POSTREPLYRES']._serialized_start=505
  _globals['_POSTREPLYRES']._serialized_end=538
  _globals['_THREADS']._serialized_start=541
  _globals['_THREADS']._serialized_end=742
# @@protoc_insertion_point(module_scope)
