# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: notification_data.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import api_pb2 as api__pb2
from . import communities_pb2 as communities__pb2
from . import discussions_pb2 as discussions__pb2
from . import events_pb2 as events__pb2
from . import requests_pb2 as requests__pb2
from . import threads_pb2 as threads__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17notification_data.proto\x12\x1eorg.couchers.notification_data\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\tapi.proto\x1a\x11\x63ommunities.proto\x1a\x11\x64iscussions.proto\x1a\x0c\x65vents.proto\x1a\x0erequests.proto\x1a\rthreads.proto\"\x8c\x01\n\x11HostRequestCreate\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12+\n\x06surfer\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0c\n\x04text\x18\x03 \x01(\t\"|\n\x11HostRequestAccept\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12)\n\x04host\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"|\n\x11HostRequestReject\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12)\n\x04host\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\x7f\n\x12HostRequestConfirm\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12+\n\x06surfer\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"~\n\x11HostRequestCancel\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12+\n\x06surfer\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\x9c\x01\n\x12HostRequestMessage\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x0f\n\x07\x61m_host\x18\x04 \x01(\x08\"\x95\x01\n\x19HostRequestMissedMessages\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0f\n\x07\x61m_host\x18\x03 \x01(\x08\"\x80\x01\n\x13HostRequestReminder\x12<\n\x0chost_request\x18\x01 \x01(\x0b\x32&.org.couchers.api.requests.HostRequest\x12+\n\x06surfer\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"K\n\x08\x42\x61\x64geAdd\x12\x10\n\x08\x62\x61\x64ge_id\x18\x01 \x01(\t\x12\x12\n\nbadge_name\x18\x02 \x01(\t\x12\x19\n\x11\x62\x61\x64ge_description\x18\x03 \x01(\t\"N\n\x0b\x42\x61\x64geRemove\x12\x10\n\x08\x62\x61\x64ge_id\x18\x01 \x01(\t\x12\x12\n\nbadge_name\x18\x02 \x01(\t\x12\x19\n\x11\x62\x61\x64ge_description\x18\x03 \x01(\t\"\"\n\x11PhoneNumberChange\x12\r\n\x05phone\x18\x01 \x01(\t\"\"\n\x11PhoneNumberVerify\x12\r\n\x05phone\x18\x01 \x01(\t\"\x1e\n\x0cGenderChange\x12\x0e\n\x06gender\x18\x01 \x01(\t\"$\n\x0f\x42irthdateChange\x12\x11\n\tbirthdate\x18\x02 \x01(\t\"F\n\x13\x46riendRequestCreate\x12/\n\nother_user\x18\x01 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"F\n\x13\x46riendRequestAccept\x12/\n\nother_user\x18\x01 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\'\n\x12\x45mailAddressChange\x12\x11\n\tnew_email\x18\x01 \x01(\t\"7\n\x10\x44onationReceived\x12\x0e\n\x06\x61mount\x18\x01 \x01(\x03\x12\x13\n\x0breceipt_url\x18\x02 \x01(\t\"2\n\x12PasswordResetStart\x12\x1c\n\x14password_reset_token\x18\x01 \x01(\t\".\n\x14\x41\x63\x63ountDeletionStart\x12\x16\n\x0e\x64\x65letion_token\x18\x01 \x01(\t\"H\n\x17\x41\x63\x63ountDeletionComplete\x12\x16\n\x0eundelete_token\x18\x01 \x01(\t\x12\x15\n\rundelete_days\x18\x02 \x01(\r\"K\n\x0c\x41piKeyCreate\x12\x0f\n\x07\x61pi_key\x18\x01 \x01(\t\x12*\n\x06\x65xpiry\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"y\n\x14\x45ventInviteOrganizer\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x32\n\rinviting_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\xda\x01\n\x0b\x45ventCreate\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x32\n\rinviting_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x10\n\x06nearby\x18\x03 \x01(\x08H\x00\x12?\n\x0cin_community\x18\x04 \x01(\x0b\x32\'.org.couchers.api.communities.CommunityH\x00\x42\x15\n\x13notification_reason\"\x87\x01\n\x0b\x45ventUpdate\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x32\n\rupdating_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x15\n\rupdated_items\x18\x03 \x03(\t\"r\n\x0b\x45ventCancel\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x34\n\x0f\x63\x61ncelling_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"<\n\x0b\x45ventDelete\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\"p\n\x0b\x43hatMessage\x12+\n\x06\x61uthor\x18\x01 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x15\n\rgroup_chat_id\x18\x04 \x01(\x04\"S\n\x12\x43hatMissedMessages\x12=\n\x08messages\x18\x01 \x03(\x0b\x32+.org.couchers.notification_data.ChatMessage\"V\n\x16ReferenceReceiveFriend\x12.\n\tfrom_user\x18\x01 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0c\n\x04text\x18\x02 \x01(\t\"t\n\x1bReferenceReceiveHostRequest\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12.\n\tfrom_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x0c\n\x04text\x18\x03 \x01(\t\"p\n\x11ReferenceReminder\x12\x17\n\x0fhost_request_id\x18\x01 \x01(\x03\x12/\n\nother_user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12\x11\n\tdays_left\x18\x03 \x01(\r\"i\n\rEventReminder\x12-\n\x05\x65vent\x18\x01 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12)\n\x04user\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"R\n\x12VerificationSVFail\x12<\n\x06reason\x18\x01 \x01(\x0e\x32,.org.couchers.notification_data.SVFailReason\"?\n\x1ePostalVerificationPostcardSent\x12\x0c\n\x04\x63ity\x18\x01 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\"h\n\x18PostalVerificationFailed\x12L\n\x06reason\x18\x01 \x01(\x0e\x32<.org.couchers.notification_data.PostalVerificationFailReason\"\x9a\x01\n\x0c\x45ventComment\x12.\n\x05reply\x18\x01 \x01(\x0b\x32\x1f.org.couchers.api.threads.Reply\x12-\n\x05\x65vent\x18\x02 \x01(\x0b\x32\x1e.org.couchers.api.events.Event\x12+\n\x06\x61uthor\x18\x03 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"}\n\x10\x44iscussionCreate\x12<\n\ndiscussion\x18\x01 \x01(\x0b\x32(.org.couchers.api.discussions.Discussion\x12+\n\x06\x61uthor\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\xae\x01\n\x11\x44iscussionComment\x12.\n\x05reply\x18\x01 \x01(\x0b\x32\x1f.org.couchers.api.threads.Reply\x12<\n\ndiscussion\x18\x02 \x01(\x0b\x32(.org.couchers.api.discussions.Discussion\x12+\n\x06\x61uthor\x18\x03 \x01(\x0b\x32\x1b.org.couchers.api.core.User\"\xeb\x01\n\x0bThreadReply\x12.\n\x05reply\x18\x01 \x01(\x0b\x32\x1f.org.couchers.api.threads.Reply\x12+\n\x06\x61uthor\x18\x02 \x01(\x0b\x32\x1b.org.couchers.api.core.User\x12/\n\x05\x65vent\x18\x03 \x01(\x0b\x32\x1e.org.couchers.api.events.EventH\x00\x12>\n\ndiscussion\x18\x04 \x01(\x0b\x32(.org.couchers.api.discussions.DiscussionH\x00\x42\x0e\n\x0creply_parent\"X\n\x0f\x41\x63tivenessProbe\x12\x17\n\x0freminder_number\x18\x01 \x01(\x04\x12,\n\x08\x64\x65\x61\x64line\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"?\n\x12GeneralNewBlogPost\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x62lurb\x18\x03 \x01(\t*\x99\x01\n\x0cSVFailReason\x12\x1a\n\x16SV_FAIL_REASON_UNKNOWN\x10\x00\x12,\n(SV_FAIL_REASON_WRONG_BIRTHDATE_OR_GENDER\x10\x01\x12!\n\x1dSV_FAIL_REASON_NOT_A_PASSPORT\x10\x02\x12\x1c\n\x18SV_FAIL_REASON_DUPLICATE\x10\x03*\xb4\x01\n\x1cPostalVerificationFailReason\x12+\n\'POSTAL_VERIFICATION_FAIL_REASON_UNKNOWN\x10\x00\x12\x30\n,POSTAL_VERIFICATION_FAIL_REASON_CODE_EXPIRED\x10\x01\x12\x35\n1POSTAL_VERIFICATION_FAIL_REASON_TOO_MANY_ATTEMPTS\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SVFAILREASON']._serialized_start=4468
  _globals['_SVFAILREASON']._serialized_end=4621
  _globals['_POSTALVERIFICATIONFAILREASON']._serialized_start=4624
  _globals['_POSTALVERIFICATIONFAILREASON']._serialized_end=4804
  _globals['_HOSTREQUESTCREATE']._serialized_start=187
  _globals['_HOSTREQUESTCREATE']._serialized_end=327
  _globals['_HOSTREQUESTACCEPT']._serialized_start=329
  _globals['_HOSTREQUESTACCEPT']._serialized_end=453
  _globals['_HOSTREQUESTREJECT']._serialized_start=455
  _globals['_HOSTREQUESTREJECT']._serialized_end=579
  _globals['_HOSTREQUESTCONFIRM']._serialized_start=581
  _globals['_HOSTREQUESTCONFIRM']._serialized_end=708
  _globals['_HOSTREQUESTCANCEL']._serialized_start=710
  _globals['_HOSTREQUESTCANCEL']._serialized_end=836
  _globals['_HOSTREQUESTMESSAGE']._serialized_start=839
  _globals['_HOSTREQUESTMESSAGE']._serialized_end=995
  _globals['_HOSTREQUESTMISSEDMESSAGES']._serialized_start=998
  _globals['_HOSTREQUESTMISSEDMESSAGES']._serialized_end=1147
  _globals['_HOSTREQUESTREMINDER']._serialized_start=1150
  _globals['_HOSTREQUESTREMINDER']._serialized_end=1278
  _globals['_BADGEADD']._serialized_start=1280
  _globals['_BADGEADD']._serialized_end=1355
  _globals['_BADGEREMOVE']._serialized_start=1357
  _globals['_BADGEREMOVE']._serialized_end=1435
  _globals['_PHONENUMBERCHANGE']._serialized_start=1437
  _globals['_PHONENUMBERCHANGE']._serialized_end=1471
  _globals['_PHONENUMBERVERIFY']._serialized_start=1473
  _globals['_PHONENUMBERVERIFY']._serialized_end=1507
  _globals['_GENDERCHANGE']._serialized_start=1509
  _globals['_GENDERCHANGE']._serialized_end=1539
  _globals['_BIRTHDATECHANGE']._serialized_start=1541
  _globals['_BIRTHDATECHANGE']._serialized_end=1577
  _globals['_FRIENDREQUESTCREATE']._serialized_start=1579
  _globals['_FRIENDREQUESTCREATE']._serialized_end=1649
  _globals['_FRIENDREQUESTACCEPT']._serialized_start=1651
  _globals['_FRIENDREQUESTACCEPT']._serialized_end=1721
  _globals['_EMAILADDRESSCHANGE']._serialized_start=1723
  _globals['_EMAILADDRESSCHANGE']._serialized_end=1762
  _globals['_DONATIONRECEIVED']._serialized_start=1764
  _globals['_DONATIONRECEIVED']._serialized_end=1819
  _globals['_PASSWORDRESETSTART']._serialized_start=1821
  _globals['_PASSWORDRESETSTART']._serialized_end=1871
  _globals['_ACCOUNTDELETIONSTART']._serialized_start=1873
  _globals['_ACCOUNTDELETIONSTART']._serialized_end=1919
  _globals['_ACCOUNTDELETIONCOMPLETE']._serialized_start=1921
  _globals['_ACCOUNTDELETIONCOMPLETE']._serialized_end=1993
  _globals['_APIKEYCREATE']._serialized_start=1995
  _globals['_APIKEYCREATE']._serialized_end=2070
  _globals['_EVENTINVITEORGANIZER']._serialized_start=2072
  _globals['_EVENTINVITEORGANIZER']._serialized_end=2193
  _globals['_EVENTCREATE']._serialized_start=2196
  _globals['_EVENTCREATE']._serialized_end=2414
  _globals['_EVENTUPDATE']._serialized_start=2417
  _globals['_EVENTUPDATE']._serialized_end=2552
  _globals['_EVENTCANCEL']._serialized_start=2554
  _globals['_EVENTCANCEL']._serialized_end=2668
  _globals['_EVENTDELETE']._serialized_start=2670
  _globals['_EVENTDELETE']._serialized_end=2730
  _globals['_CHATMESSAGE']._serialized_start=2732
  _globals['_CHATMESSAGE']._serialized_end=2844
  _globals['_CHATMISSEDMESSAGES']._serialized_start=2846
  _globals['_CHATMISSEDMESSAGES']._serialized_end=2929
  _globals['_REFERENCERECEIVEFRIEND']._serialized_start=2931
  _globals['_REFERENCERECEIVEFRIEND']._serialized_end=3017
  _globals['_REFERENCERECEIVEHOSTREQUEST']._serialized_start=3019
  _globals['_REFERENCERECEIVEHOSTREQUEST']._serialized_end=3135
  _globals['_REFERENCEREMINDER']._serialized_start=3137
  _globals['_REFERENCEREMINDER']._serialized_end=3249
  _globals['_EVENTREMINDER']._serialized_start=3251
  _globals['_EVENTREMINDER']._serialized_end=3356
  _globals['_VERIFICATIONSVFAIL']._serialized_start=3358
  _globals['_VERIFICATIONSVFAIL']._serialized_end=3440
  _globals['_POSTALVERIFICATIONPOSTCARDSENT']._serialized_start=3442
  _globals['_POSTALVERIFICATIONPOSTCARDSENT']._serialized_end=3505
  _globals['_POSTALVERIFICATIONFAILED']._serialized_start=3507
  _globals['_POSTALVERIFICATIONFAILED']._serialized_end=3611
  _globals['_EVENTCOMMENT']._serialized_start=3614
  _globals['_EVENTCOMMENT']._serialized_end=3768
  _globals['_DISCUSSIONCREATE']._serialized_start=3770
  _globals['_DISCUSSIONCREATE']._serialized_end=3895
  _globals['_DISCUSSIONCOMMENT']._serialized_start=3898
  _globals['_DISCUSSIONCOMMENT']._serialized_end=4072
  _globals['_THREADREPLY']._serialized_start=4075
  _globals['_THREADREPLY']._serialized_end=4310
  _globals['_ACTIVENESSPROBE']._serialized_start=4312
  _globals['_ACTIVENESSPROBE']._serialized_end=4400
  _globals['_GENERALNEWBLOGPOST']._serialized_start=4402
  _globals['_GENERALNEWBLOGPOST']._serialized_end=4465
# @@protoc_insertion_point(module_scope)
