from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.api.httpbody_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import public_pb2
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class PublicServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetPublicUsers(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.api.httpbody_pb2.HttpBody, collections.abc.Awaitable[google.api.httpbody_pb2.HttpBody]]: ...

    @abc.abstractmethod
    def GetPublicUser(
        self,
        request: public_pb2.GetPublicUserReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[public_pb2.GetPublicUserRes, collections.abc.Awaitable[public_pb2.GetPublicUserRes]]: ...

    @abc.abstractmethod
    def GetSignupPageInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[public_pb2.GetSignupPageInfoRes, collections.abc.Awaitable[public_pb2.GetSignupPageInfoRes]]: ...

    @abc.abstractmethod
    def GetVolunteers(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[public_pb2.GetVolunteersRes, collections.abc.Awaitable[public_pb2.GetVolunteersRes]]: ...

    @abc.abstractmethod
    def GetDonationStats(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[public_pb2.GetDonationStatsRes, collections.abc.Awaitable[public_pb2.GetDonationStatsRes]]: ...

def add_PublicServicer_to_server(servicer: PublicServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
