from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import notifications_pb2
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class NotificationsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetNotificationSettings(
        self,
        request: notifications_pb2.GetNotificationSettingsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[notifications_pb2.GetNotificationSettingsRes, collections.abc.Awaitable[notifications_pb2.GetNotificationSettingsRes]]: ...

    @abc.abstractmethod
    def SetNotificationSettings(
        self,
        request: notifications_pb2.SetNotificationSettingsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[notifications_pb2.GetNotificationSettingsRes, collections.abc.Awaitable[notifications_pb2.GetNotificationSettingsRes]]: ...

    @abc.abstractmethod
    def ListNotifications(
        self,
        request: notifications_pb2.ListNotificationsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[notifications_pb2.ListNotificationsRes, collections.abc.Awaitable[notifications_pb2.ListNotificationsRes]]: ...

    @abc.abstractmethod
    def MarkNotificationSeen(
        self,
        request: notifications_pb2.MarkNotificationSeenReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def MarkAllNotificationsSeen(
        self,
        request: notifications_pb2.MarkAllNotificationsSeenReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def GetVapidPublicKey(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[notifications_pb2.GetVapidPublicKeyRes, collections.abc.Awaitable[notifications_pb2.GetVapidPublicKeyRes]]: ...

    @abc.abstractmethod
    def RegisterPushNotificationSubscription(
        self,
        request: notifications_pb2.RegisterPushNotificationSubscriptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def SendTestPushNotification(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def RegisterMobilePushNotificationSubscription(
        self,
        request: notifications_pb2.RegisterMobilePushNotificationSubscriptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

    @abc.abstractmethod
    def SendTestMobilePushNotification(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]: ...

def add_NotificationsServicer_to_server(servicer: NotificationsServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
