# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: jail.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2
from . import account_pb2 as account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\njail.proto\x12\x11org.couchers.jail\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\x1a\raccount.proto\"\x8f\x02\n\x0bJailInfoRes\x12\x0e\n\x06jailed\x18\x01 \x01(\x08\x12\x1c\n\x14has_not_accepted_tos\x18\x02 \x01(\x08\x12 \n\x18needs_to_update_location\x18\x03 \x01(\x08\x12-\n%has_not_accepted_community_guidelines\x18\x04 \x01(\x08\x12\x1d\n\x15has_pending_mod_notes\x18\x06 \x01(\x08\x12<\n\x11pending_mod_notes\x18\x07 \x03(\x0b\x32!.org.couchers.api.account.ModNote\x12$\n\x1chas_pending_activeness_probe\x18\x08 \x01(\x08\"\x1e\n\x0c\x41\x63\x63\x65ptTOSReq\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x01 \x01(\x08\"H\n\x0eSetLocationReq\x12\x0c\n\x04\x63ity\x18\x01 \x01(\t\x12\x0b\n\x03lat\x18\x02 \x01(\x01\x12\x0b\n\x03lng\x18\x03 \x01(\x01\x12\x0e\n\x06radius\x18\x04 \x01(\x01\".\n\x1c\x41\x63\x63\x65ptCommunityGuidelinesReq\x12\x0e\n\x06\x61\x63\x63\x65pt\x18\x01 \x01(\x08\"D\n\x1c\x41\x63knowledgePendingModNoteReq\x12\x0f\n\x07note_id\x18\x01 \x01(\x04\x12\x13\n\x0b\x61\x63knowledge\x18\x02 \x01(\x08\"[\n\x1bRespondToActivenessProbeReq\x12<\n\x08response\x18\x01 \x01(\x0e\x32*.org.couchers.jail.ActivenessProbeResponse*\x9c\x01\n\x17\x41\x63tivenessProbeResponse\x12%\n!ACTIVENESS_PROBE_RESPONSE_UNKNOWN\x10\x00\x12*\n&ACTIVENESS_PROBE_RESPONSE_STILL_ACTIVE\x10\x01\x12.\n*ACTIVENESS_PROBE_RESPONSE_NO_LONGER_ACTIVE\x10\x02\x32\xc4\x04\n\x04Jail\x12\x44\n\x08JailInfo\x12\x16.google.protobuf.Empty\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12N\n\tAcceptTOS\x12\x1f.org.couchers.jail.AcceptTOSReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12R\n\x0bSetLocation\x12!.org.couchers.jail.SetLocationReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12n\n\x19\x41\x63\x63\x65ptCommunityGuidelines\x12/.org.couchers.jail.AcceptCommunityGuidelinesReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12n\n\x19\x41\x63knowledgePendingModNote\x12/.org.couchers.jail.AcknowledgePendingModNoteReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x12l\n\x18RespondToActivenessProbe\x12..org.couchers.jail.RespondToActivenessProbeReq\x1a\x1e.org.couchers.jail.JailInfoRes\"\x00\x1a\x04\x88\xb5\x18\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'jail_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_JAIL']._loaded_options = None
  _globals['_JAIL']._serialized_options = b'\210\265\030\002'
  _globals['_ACTIVENESSPROBERESPONSE']._serialized_start=688
  _globals['_ACTIVENESSPROBERESPONSE']._serialized_end=844
  _globals['_JAILINFORES']._serialized_start=97
  _globals['_JAILINFORES']._serialized_end=368
  _globals['_ACCEPTTOSREQ']._serialized_start=370
  _globals['_ACCEPTTOSREQ']._serialized_end=400
  _globals['_SETLOCATIONREQ']._serialized_start=402
  _globals['_SETLOCATIONREQ']._serialized_end=474
  _globals['_ACCEPTCOMMUNITYGUIDELINESREQ']._serialized_start=476
  _globals['_ACCEPTCOMMUNITYGUIDELINESREQ']._serialized_end=522
  _globals['_ACKNOWLEDGEPENDINGMODNOTEREQ']._serialized_start=524
  _globals['_ACKNOWLEDGEPENDINGMODNOTEREQ']._serialized_end=592
  _globals['_RESPONDTOACTIVENESSPROBEREQ']._serialized_start=594
  _globals['_RESPONDTOACTIVENESSPROBEREQ']._serialized_end=685
  _globals['_JAIL']._serialized_start=847
  _globals['_JAIL']._serialized_end=1427
# @@protoc_insertion_point(module_scope)
