from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import pages_pb2
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class PagesServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreatePlace(
        self,
        request: pages_pb2.CreatePlaceReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.Page, collections.abc.Awaitable[pages_pb2.Page]]:
        """Creates a place"""

    @abc.abstractmethod
    def CreateGuide(
        self,
        request: pages_pb2.CreateGuideReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.Page, collections.abc.Awaitable[pages_pb2.Page]]:
        """Creates a guide"""

    @abc.abstractmethod
    def GetPage(
        self,
        request: pages_pb2.GetPageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.Page, collections.abc.Awaitable[pages_pb2.Page]]:
        """Gets a page"""

    @abc.abstractmethod
    def UpdatePage(
        self,
        request: pages_pb2.UpdatePageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.Page, collections.abc.Awaitable[pages_pb2.Page]]:
        """Edit a page"""

    @abc.abstractmethod
    def TransferPage(
        self,
        request: pages_pb2.TransferPageReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.Page, collections.abc.Awaitable[pages_pb2.Page]]:
        """Transfer a page you own to either a group or a community"""

    @abc.abstractmethod
    def ListUserPlaces(
        self,
        request: pages_pb2.ListUserPlacesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.ListUserPlacesRes, collections.abc.Awaitable[pages_pb2.ListUserPlacesRes]]:
        """Gets a list of places pages a user owns"""

    @abc.abstractmethod
    def ListUserGuides(
        self,
        request: pages_pb2.ListUserGuidesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[pages_pb2.ListUserGuidesRes, collections.abc.Awaitable[pages_pb2.ListUserGuidesRes]]:
        """Gets a list of guide pages a user owns"""

def add_PagesServicer_to_server(servicer: PagesServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
