"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PhotoGalleryItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ITEM_ID_FIELD_NUMBER: builtins.int
    FULL_URL_FIELD_NUMBER: builtins.int
    THUMBNAIL_URL_FIELD_NUMBER: builtins.int
    CAPTION_FIELD_NUMBER: builtins.int
    item_id: builtins.int
    full_url: builtins.str
    thumbnail_url: builtins.str
    caption: builtins.str
    """Photos are returned in order, no position field needed"""
    def __init__(
        self,
        *,
        item_id: builtins.int | None = ...,
        full_url: builtins.str | None = ...,
        thumbnail_url: builtins.str | None = ...,
        caption: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["caption", b"caption", "full_url", b"full_url", "item_id", b"item_id", "thumbnail_url", b"thumbnail_url"]) -> None: ...

Global___PhotoGalleryItem: typing_extensions.TypeAlias = PhotoGalleryItem

@typing.final
class PhotoGallery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    PHOTOS_FIELD_NUMBER: builtins.int
    CAN_EDIT_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    can_edit: builtins.bool
    @property
    def photos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___PhotoGalleryItem]: ...
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        photos: collections.abc.Iterable[Global___PhotoGalleryItem] | None = ...,
        can_edit: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["can_edit", b"can_edit", "gallery_id", b"gallery_id", "photos", b"photos"]) -> None: ...

Global___PhotoGallery: typing_extensions.TypeAlias = PhotoGallery

@typing.final
class GetGalleryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gallery_id", b"gallery_id"]) -> None: ...

Global___GetGalleryReq: typing_extensions.TypeAlias = GetGalleryReq

@typing.final
class AddPhotoToGalleryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    UPLOAD_KEY_FIELD_NUMBER: builtins.int
    CAPTION_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    upload_key: builtins.str
    caption: builtins.str
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        upload_key: builtins.str | None = ...,
        caption: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["caption", b"caption", "gallery_id", b"gallery_id", "upload_key", b"upload_key"]) -> None: ...

Global___AddPhotoToGalleryReq: typing_extensions.TypeAlias = AddPhotoToGalleryReq

@typing.final
class RemovePhotoFromGalleryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    item_id: builtins.int
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        item_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gallery_id", b"gallery_id", "item_id", b"item_id"]) -> None: ...

Global___RemovePhotoFromGalleryReq: typing_extensions.TypeAlias = RemovePhotoFromGalleryReq

@typing.final
class MovePhotoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    AFTER_ITEM_ID_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    item_id: builtins.int
    after_item_id: builtins.int
    """ID of photo to place this one after, or 0 to move to first position"""
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        item_id: builtins.int | None = ...,
        after_item_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["after_item_id", b"after_item_id", "gallery_id", b"gallery_id", "item_id", b"item_id"]) -> None: ...

Global___MovePhotoReq: typing_extensions.TypeAlias = MovePhotoReq

@typing.final
class UpdatePhotoCaptionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    ITEM_ID_FIELD_NUMBER: builtins.int
    CAPTION_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    item_id: builtins.int
    caption: builtins.str
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        item_id: builtins.int | None = ...,
        caption: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["caption", b"caption", "gallery_id", b"gallery_id", "item_id", b"item_id"]) -> None: ...

Global___UpdatePhotoCaptionReq: typing_extensions.TypeAlias = UpdatePhotoCaptionReq

@typing.final
class GetGalleryEditInfoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gallery_id", b"gallery_id"]) -> None: ...

Global___GetGalleryEditInfoReq: typing_extensions.TypeAlias = GetGalleryEditInfoReq

@typing.final
class GetGalleryEditInfoRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GALLERY_ID_FIELD_NUMBER: builtins.int
    MAX_PHOTOS_FIELD_NUMBER: builtins.int
    CURRENT_PHOTO_COUNT_FIELD_NUMBER: builtins.int
    gallery_id: builtins.int
    max_photos: builtins.int
    current_photo_count: builtins.int
    def __init__(
        self,
        *,
        gallery_id: builtins.int | None = ...,
        max_photos: builtins.int | None = ...,
        current_photo_count: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["current_photo_count", b"current_photo_count", "gallery_id", b"gallery_id", "max_photos", b"max_photos"]) -> None: ...

Global___GetGalleryEditInfoRes: typing_extensions.TypeAlias = GetGalleryEditInfoRes
