# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: groups.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import discussions_pb2 as discussions__pb2
from . import events_pb2 as events__pb2
from . import pages_pb2 as pages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cgroups.proto\x12\x17org.couchers.api.groups\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\x11\x64iscussions.proto\x1a\x0c\x65vents.proto\x1a\x0bpages.proto\"X\n\x0f\x43ommunityParent\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"P\n\x0bGroupParent\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\x88\x01\n\x06Parent\x12=\n\tcommunity\x18\x01 \x01(\x0b\x32(.org.couchers.api.groups.CommunityParentH\x00\x12\x35\n\x05group\x18\x02 \x01(\x0b\x32$.org.couchers.api.groups.GroupParentH\x00\x42\x08\n\x06parent\"\xba\x02\n\x05Group\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04slug\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12+\n\x07\x63reated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x07parents\x18\x06 \x03(\x0b\x32\x1f.org.couchers.api.groups.Parent\x12/\n\tmain_page\x18\x07 \x01(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x0e\n\x06member\x18\x08 \x01(\x08\x12\r\n\x05\x61\x64min\x18\t \x01(\x08\x12\x14\n\x0cmember_count\x18\n \x01(\r\x12\x13\n\x0b\x61\x64min_count\x18\x0b \x01(\r\x12\x14\n\x0c\x63\x61n_moderate\x18\x0c \x01(\x08\"\x1f\n\x0bGetGroupReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\"H\n\rListAdminsReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"@\n\rListAdminsRes\x12\x16\n\x0e\x61\x64min_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"I\n\x0eListMembersReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"B\n\x0eListMembersRes\x12\x17\n\x0fmember_user_ids\x18\x01 \x03(\x03\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"H\n\rListPlacesReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListPlacesRes\x12,\n\x06places\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"H\n\rListGuidesReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"V\n\rListGuidesRes\x12,\n\x06guides\x18\x01 \x03(\x0b\x32\x1c.org.couchers.api.pages.Page\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"V\n\rListEventsReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x0c\n\x04past\x18\x04 \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"X\n\rListEventsRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"M\n\x12ListDiscussionsReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"l\n\x12ListDiscussionsRes\x12=\n\x0b\x64iscussions\x18\x01 \x03(\x0b\x32(.org.couchers.api.discussions.Discussion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\" \n\x0cJoinGroupReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\"!\n\rLeaveGroupReq\x12\x10\n\x08group_id\x18\x01 \x01(\x03\"K\n\x11ListUserGroupsReq\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"\\\n\x11ListUserGroupsRes\x12.\n\x06groups\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.groups.Group\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xbe\x07\n\x06Groups\x12R\n\x08GetGroup\x12$.org.couchers.api.groups.GetGroupReq\x1a\x1e.org.couchers.api.groups.Group\"\x00\x12^\n\nListAdmins\x12&.org.couchers.api.groups.ListAdminsReq\x1a&.org.couchers.api.groups.ListAdminsRes\"\x00\x12\x61\n\x0bListMembers\x12\'.org.couchers.api.groups.ListMembersReq\x1a\'.org.couchers.api.groups.ListMembersRes\"\x00\x12^\n\nListPlaces\x12&.org.couchers.api.groups.ListPlacesReq\x1a&.org.couchers.api.groups.ListPlacesRes\"\x00\x12^\n\nListGuides\x12&.org.couchers.api.groups.ListGuidesReq\x1a&.org.couchers.api.groups.ListGuidesRes\"\x00\x12^\n\nListEvents\x12&.org.couchers.api.groups.ListEventsReq\x1a&.org.couchers.api.groups.ListEventsRes\"\x00\x12m\n\x0fListDiscussions\x12+.org.couchers.api.groups.ListDiscussionsReq\x1a+.org.couchers.api.groups.ListDiscussionsRes\"\x00\x12L\n\tJoinGroup\x12%.org.couchers.api.groups.JoinGroupReq\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\nLeaveGroup\x12&.org.couchers.api.groups.LeaveGroupReq\x1a\x16.google.protobuf.Empty\"\x00\x12j\n\x0eListUserGroups\x12*.org.couchers.api.groups.ListUserGroupsReq\x1a*.org.couchers.api.groups.ListUserGroupsRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'groups_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GROUPS']._loaded_options = None
  _globals['_GROUPS']._serialized_options = b'\210\265\030\003'
  _globals['_COMMUNITYPARENT']._serialized_start=168
  _globals['_COMMUNITYPARENT']._serialized_end=256
  _globals['_GROUPPARENT']._serialized_start=258
  _globals['_GROUPPARENT']._serialized_end=338
  _globals['_PARENT']._serialized_start=341
  _globals['_PARENT']._serialized_end=477
  _globals['_GROUP']._serialized_start=480
  _globals['_GROUP']._serialized_end=794
  _globals['_GETGROUPREQ']._serialized_start=796
  _globals['_GETGROUPREQ']._serialized_end=827
  _globals['_LISTADMINSREQ']._serialized_start=829
  _globals['_LISTADMINSREQ']._serialized_end=901
  _globals['_LISTADMINSRES']._serialized_start=903
  _globals['_LISTADMINSRES']._serialized_end=967
  _globals['_LISTMEMBERSREQ']._serialized_start=969
  _globals['_LISTMEMBERSREQ']._serialized_end=1042
  _globals['_LISTMEMBERSRES']._serialized_start=1044
  _globals['_LISTMEMBERSRES']._serialized_end=1110
  _globals['_LISTPLACESREQ']._serialized_start=1112
  _globals['_LISTPLACESREQ']._serialized_end=1184
  _globals['_LISTPLACESRES']._serialized_start=1186
  _globals['_LISTPLACESRES']._serialized_end=1272
  _globals['_LISTGUIDESREQ']._serialized_start=1274
  _globals['_LISTGUIDESREQ']._serialized_end=1346
  _globals['_LISTGUIDESRES']._serialized_start=1348
  _globals['_LISTGUIDESRES']._serialized_end=1434
  _globals['_LISTEVENTSREQ']._serialized_start=1436
  _globals['_LISTEVENTSREQ']._serialized_end=1522
  _globals['_LISTEVENTSRES']._serialized_start=1524
  _globals['_LISTEVENTSRES']._serialized_end=1612
  _globals['_LISTDISCUSSIONSREQ']._serialized_start=1614
  _globals['_LISTDISCUSSIONSREQ']._serialized_end=1691
  _globals['_LISTDISCUSSIONSRES']._serialized_start=1693
  _globals['_LISTDISCUSSIONSRES']._serialized_end=1801
  _globals['_JOINGROUPREQ']._serialized_start=1803
  _globals['_JOINGROUPREQ']._serialized_end=1835
  _globals['_LEAVEGROUPREQ']._serialized_start=1837
  _globals['_LEAVEGROUPREQ']._serialized_end=1870
  _globals['_LISTUSERGROUPSREQ']._serialized_start=1872
  _globals['_LISTUSERGROUPSREQ']._serialized_end=1947
  _globals['_LISTUSERGROUPSRES']._serialized_start=1949
  _globals['_LISTUSERGROUPSRES']._serialized_end=2041
  _globals['_GROUPS']._serialized_start=2044
  _globals['_GROUPS']._serialized_end=3002
# @@protoc_insertion_point(module_scope)
