# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: feature_requests.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x66\x65\x61ture_requests.proto\x12!org.couchers.api.feature_requests\x1a\x11\x61nnotations.proto\">\n\x15GetFeatureRequestsReq\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"\xd8\x01\n\x0e\x46\x65\x61tureRequest\x12\x1a\n\x12\x66\x65\x61ture_request_id\x18\x01 \x01(\x03\x12\x17\n\x0f\x63reator_user_id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x41\n\x0c\x63urrent_vote\x18\x05 \x01(\x0e\x32+.org.couchers.api.feature_requests.VoteType\x12\x15\n\rtotal_upvotes\x18\x06 \x01(\r\x12\x17\n\x0ftotal_downvotes\x18\x07 \x01(\r\"{\n\x15GetFeatureRequestsRes\x12I\n\x0e\x46\x65\x61tureRequest\x18\x01 \x03(\x0b\x32\x31.org.couchers.api.feature_requests.FeatureRequest\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x17\x43reateFeatureRequestReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"p\n\x17VoteOnFeatureRequestReq\x12\x1a\n\x12\x66\x65\x61ture_request_id\x18\x01 \x01(\x03\x12\x39\n\x04vote\x18\x02 \x01(\x0e\x32+.org.couchers.api.feature_requests.VoteType*j\n\x08VoteType\x12\x15\n\x11VOTE_TYPE_UNKNOWN\x10\x00\x12\x17\n\x13VOTE_TYPE_NOT_VOTED\x10\x01\x12\x15\n\x11VOTE_TYPE_UPVOTED\x10\x02\x12\x17\n\x13VOTE_TYPE_DOWNVOTED\x10\x03\x32\xb2\x03\n\x0f\x46\x65\x61tureRequests\x12\x88\x01\n\x12GetFeatureRequests\x12\x38.org.couchers.api.feature_requests.GetFeatureRequestsReq\x1a\x38.org.couchers.api.feature_requests.GetFeatureRequestsRes\x12\x85\x01\n\x14\x43reateFeatureRequest\x12:.org.couchers.api.feature_requests.CreateFeatureRequestReq\x1a\x31.org.couchers.api.feature_requests.FeatureRequest\x12\x85\x01\n\x14VoteOnFeatureRequest\x12:.org.couchers.api.feature_requests.VoteOnFeatureRequestReq\x1a\x31.org.couchers.api.feature_requests.FeatureRequest\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'feature_requests_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FEATUREREQUESTS']._loaded_options = None
  _globals['_FEATUREREQUESTS']._serialized_options = b'\210\265\030\003'
  _globals['_VOTETYPE']._serialized_start=661
  _globals['_VOTETYPE']._serialized_end=767
  _globals['_GETFEATUREREQUESTSREQ']._serialized_start=80
  _globals['_GETFEATUREREQUESTSREQ']._serialized_end=142
  _globals['_FEATUREREQUEST']._serialized_start=145
  _globals['_FEATUREREQUEST']._serialized_end=361
  _globals['_GETFEATUREREQUESTSRES']._serialized_start=363
  _globals['_GETFEATUREREQUESTSRES']._serialized_end=486
  _globals['_CREATEFEATUREREQUESTREQ']._serialized_start=488
  _globals['_CREATEFEATUREREQUESTREQ']._serialized_end=545
  _globals['_VOTEONFEATUREREQUESTREQ']._serialized_start=547
  _globals['_VOTEONFEATUREREQUESTREQ']._serialized_end=659
  _globals['_FEATUREREQUESTS']._serialized_start=770
  _globals['_FEATUREREQUESTS']._serialized_end=1204
# @@protoc_insertion_point(module_scope)
