from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import discussions_pb2
import grpc
import grpc.aio
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class DiscussionsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateDiscussion(
        self,
        request: discussions_pb2.CreateDiscussionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[discussions_pb2.Discussion, collections.abc.Awaitable[discussions_pb2.Discussion]]:
        """Create a new discussion"""

    @abc.abstractmethod
    def GetDiscussion(
        self,
        request: discussions_pb2.GetDiscussionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[discussions_pb2.Discussion, collections.abc.Awaitable[discussions_pb2.Discussion]]:
        """Retrieve a discussion"""

def add_DiscussionsServicer_to_server(servicer: DiscussionsServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
