"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ReportReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REASON_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONTENT_REF_FIELD_NUMBER: builtins.int
    AUTHOR_USER_FIELD_NUMBER: builtins.int
    USER_AGENT_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    reason: builtins.str
    """e.g. spam, inappropriate"""
    description: builtins.str
    """short description"""
    content_ref: builtins.str
    """a reference to the content being reported, this should be filled out by the UI automatically, see
    //docs/content_ref.md
    """
    author_user: builtins.str
    """the id or username of the author of this piece of content"""
    user_agent: builtins.str
    """the browser's user-agent if available"""
    page: builtins.str
    """url that the user was on when they reported"""
    def __init__(
        self,
        *,
        reason: builtins.str | None = ...,
        description: builtins.str | None = ...,
        content_ref: builtins.str | None = ...,
        author_user: builtins.str | None = ...,
        user_agent: builtins.str | None = ...,
        page: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["author_user", b"author_user", "content_ref", b"content_ref", "description", b"description", "page", b"page", "reason", b"reason", "user_agent", b"user_agent"]) -> None: ...

Global___ReportReq: typing_extensions.TypeAlias = ReportReq
