from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Messages between main and media server"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import media_pb2
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class MediaServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def UploadConfirmation(
        self,
        request: media_pb2.UploadConfirmationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """when an upload completes, the upload server confirms to the main server
        that the upload succeeded using this function
        """

def add_MediaServicer_to_server(servicer: MediaServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
