# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: media.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bmedia.proto\x12\x12org.couchers.media\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf1\x01\n\rUploadRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12:\n\x04type\x18\x02 \x01(\x0e\x32,.org.couchers.media.UploadRequest.UploadType\x12+\n\x07\x63reated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65xpiry\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tmax_width\x18\x05 \x01(\r\x12\x12\n\nmax_height\x18\x06 \x01(\r\"\x17\n\nUploadType\x12\t\n\x05IMAGE\x10\x00\"6\n\x15UploadConfirmationReq\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t2b\n\x05Media\x12Y\n\x12UploadConfirmation\x12).org.couchers.media.UploadConfirmationReq\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'media_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_UPLOADREQUEST']._serialized_start=98
  _globals['_UPLOADREQUEST']._serialized_end=339
  _globals['_UPLOADREQUEST_UPLOADTYPE']._serialized_start=316
  _globals['_UPLOADREQUEST_UPLOADTYPE']._serialized_end=339
  _globals['_UPLOADCONFIRMATIONREQ']._serialized_start=341
  _globals['_UPLOADCONFIRMATIONREQ']._serialized_end=395
  _globals['_MEDIA']._serialized_start=397
  _globals['_MEDIA']._serialized_end=495
# @@protoc_insertion_point(module_scope)
