# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: feature_suggestions.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x66\x65\x61ture_suggestions.proto\x12$org.couchers.api.feature_suggestions\x1a\x11\x61nnotations.proto\"B\n\x19ListFeatureSuggestionsReq\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"\xe1\x01\n\x11\x46\x65\x61tureSuggestion\x12\x1d\n\x15\x66\x65\x61ture_suggestion_id\x18\x01 \x01(\x03\x12\x17\n\x0f\x63reator_user_id\x18\x02 \x01(\x03\x12\r\n\x05title\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x44\n\x0c\x63urrent_vote\x18\x05 \x01(\x0e\x32..org.couchers.api.feature_suggestions.VoteType\x12\x15\n\rtotal_upvotes\x18\x06 \x01(\r\x12\x17\n\x0ftotal_downvotes\x18\x07 \x01(\r\"\x88\x01\n\x19ListFeatureSuggestionsRes\x12R\n\x11\x46\x65\x61tureSuggestion\x18\x01 \x03(\x0b\x32\x37.org.couchers.api.feature_suggestions.FeatureSuggestion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"<\n\x1a\x43reateFeatureSuggestionReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\"y\n\x1aVoteOnFeatureSuggestionReq\x12\x1d\n\x15\x66\x65\x61ture_suggestion_id\x18\x01 \x01(\x03\x12<\n\x04vote\x18\x02 \x01(\x0e\x32..org.couchers.api.feature_suggestions.VoteType*j\n\x08VoteType\x12\x15\n\x11VOTE_TYPE_UNKNOWN\x10\x00\x12\x17\n\x13VOTE_TYPE_NOT_VOTED\x10\x01\x12\x15\n\x11VOTE_TYPE_UPVOTED\x10\x02\x12\x17\n\x13VOTE_TYPE_DOWNVOTED\x10\x03\x32\xe5\x03\n\x12\x46\x65\x61tureSuggestions\x12\x9a\x01\n\x16ListFeatureSuggestions\x12?.org.couchers.api.feature_suggestions.ListFeatureSuggestionsReq\x1a?.org.couchers.api.feature_suggestions.ListFeatureSuggestionsRes\x12\x94\x01\n\x17\x43reateFeatureSuggestion\x12@.org.couchers.api.feature_suggestions.CreateFeatureSuggestionReq\x1a\x37.org.couchers.api.feature_suggestions.FeatureSuggestion\x12\x94\x01\n\x17VoteOnFeatureSuggestion\x12@.org.couchers.api.feature_suggestions.VoteOnFeatureSuggestionReq\x1a\x37.org.couchers.api.feature_suggestions.FeatureSuggestion\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'feature_suggestions_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FEATURESUGGESTIONS']._loaded_options = None
  _globals['_FEATURESUGGESTIONS']._serialized_options = b'\210\265\030\003'
  _globals['_VOTETYPE']._serialized_start=706
  _globals['_VOTETYPE']._serialized_end=812
  _globals['_LISTFEATURESUGGESTIONSREQ']._serialized_start=86
  _globals['_LISTFEATURESUGGESTIONSREQ']._serialized_end=152
  _globals['_FEATURESUGGESTION']._serialized_start=155
  _globals['_FEATURESUGGESTION']._serialized_end=380
  _globals['_LISTFEATURESUGGESTIONSRES']._serialized_start=383
  _globals['_LISTFEATURESUGGESTIONSRES']._serialized_end=519
  _globals['_CREATEFEATURESUGGESTIONREQ']._serialized_start=521
  _globals['_CREATEFEATURESUGGESTIONREQ']._serialized_end=581
  _globals['_VOTEONFEATURESUGGESTIONREQ']._serialized_start=583
  _globals['_VOTEONFEATURESUGGESTIONREQ']._serialized_end=704
  _globals['_FEATURESUGGESTIONS']._serialized_start=815
  _globals['_FEATURESUGGESTIONS']._serialized_end=1300
# @@protoc_insertion_point(module_scope)
