"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class VersionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    version: builtins.str
    def __init__(
        self,
        *,
        version: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["version", b"version"]) -> None: ...

Global___VersionInfo: typing_extensions.TypeAlias = VersionInfo

@typing.final
class ScreenResolution(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    width: builtins.int
    height: builtins.int
    def __init__(
        self,
        *,
        width: builtins.int | None = ...,
        height: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["height", b"height", "width", b"width"]) -> None: ...

Global___ScreenResolution: typing_extensions.TypeAlias = ScreenResolution

@typing.final
class ReportBugReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RESULTS_FIELD_NUMBER: builtins.int
    FRONTEND_VERSION_FIELD_NUMBER: builtins.int
    USER_AGENT_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    SCREEN_RESOLUTION_FIELD_NUMBER: builtins.int
    subject: builtins.str
    description: builtins.str
    results: builtins.str
    frontend_version: builtins.str
    user_agent: builtins.str
    page: builtins.str
    @property
    def screen_resolution(self) -> Global___ScreenResolution: ...
    def __init__(
        self,
        *,
        subject: builtins.str | None = ...,
        description: builtins.str | None = ...,
        results: builtins.str | None = ...,
        frontend_version: builtins.str | None = ...,
        user_agent: builtins.str | None = ...,
        page: builtins.str | None = ...,
        screen_resolution: Global___ScreenResolution | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["screen_resolution", b"screen_resolution"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "frontend_version", b"frontend_version", "page", b"page", "results", b"results", "screen_resolution", b"screen_resolution", "subject", b"subject", "user_agent", b"user_agent"]) -> None: ...

Global___ReportBugReq: typing_extensions.TypeAlias = ReportBugReq

@typing.final
class ReportBugRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUG_ID_FIELD_NUMBER: builtins.int
    BUG_URL_FIELD_NUMBER: builtins.int
    bug_id: builtins.str
    bug_url: builtins.str
    def __init__(
        self,
        *,
        bug_id: builtins.str | None = ...,
        bug_url: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bug_id", b"bug_id", "bug_url", b"bug_url"]) -> None: ...

Global___ReportBugRes: typing_extensions.TypeAlias = ReportBugRes

@typing.final
class StatusReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NONCE_FIELD_NUMBER: builtins.int
    nonce: builtins.str
    def __init__(
        self,
        *,
        nonce: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["nonce", b"nonce"]) -> None: ...

Global___StatusReq: typing_extensions.TypeAlias = StatusReq

@typing.final
class StatusRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NONCE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    COUCHER_COUNT_FIELD_NUMBER: builtins.int
    nonce: builtins.str
    version: builtins.str
    coucher_count: builtins.int
    def __init__(
        self,
        *,
        nonce: builtins.str | None = ...,
        version: builtins.str | None = ...,
        coucher_count: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["coucher_count", b"coucher_count", "nonce", b"nonce", "version", b"version"]) -> None: ...

Global___StatusRes: typing_extensions.TypeAlias = StatusRes

@typing.final
class GeolocationSearchInfoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_STRING_FIELD_NUMBER: builtins.int
    NOMINATIM_RESULT_JSON_FIELD_NUMBER: builtins.int
    FORMATTED_RESULT_JSON_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    search_string: builtins.str
    nominatim_result_json: builtins.str
    formatted_result_json: builtins.str
    duration_ms: builtins.int
    def __init__(
        self,
        *,
        search_string: builtins.str | None = ...,
        nominatim_result_json: builtins.str | None = ...,
        formatted_result_json: builtins.str | None = ...,
        duration_ms: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["duration_ms", b"duration_ms", "formatted_result_json", b"formatted_result_json", "nominatim_result_json", b"nominatim_result_json", "search_string", b"search_string"]) -> None: ...

Global___GeolocationSearchInfoReq: typing_extensions.TypeAlias = GeolocationSearchInfoReq

@typing.final
class GeolocationClickInfoReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTEXT_FIELD_NUMBER: builtins.int
    FORMATTED_RESULT_JSON_FIELD_NUMBER: builtins.int
    SEARCH_CHOICE_JSON_FIELD_NUMBER: builtins.int
    context: builtins.str
    formatted_result_json: builtins.str
    search_choice_json: builtins.str
    def __init__(
        self,
        *,
        context: builtins.str | None = ...,
        formatted_result_json: builtins.str | None = ...,
        search_choice_json: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["context", b"context", "formatted_result_json", b"formatted_result_json", "search_choice_json", b"search_choice_json"]) -> None: ...

Global___GeolocationClickInfoReq: typing_extensions.TypeAlias = GeolocationClickInfoReq
